@@ -15,9 +15,21 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "dirfile.h"
-#include "getdata.h"
-#include "getdata_struct.h"
+
+#ifdef HAVE_EXTERNAL_GETDATA
+#include <getdata.h>
+#include <getdata_struct.h>
+#define FIELD_LENGTH 1024
+#else
+#include "old_getdata.h"
+#include "old_getdata_struct.h"
+#endif
+
 #include "kstdebug.h"
 
 DirFileSource::DirFileSource(KConfig *cfg, const QString& filename, const QString& type)
@@ -35,6 +47,7 @@ DirFileSource::~DirFileSource() {
 bool DirFileSource::reset() {
   _fieldList.clear();
   init();
+
   return true;
 }
 
@@ -89,16 +102,18 @@ KstObject::UpdateType DirFileSource::update(int u) {
   }
 
   int err = 0;
-  // The magic minus two here has been extracted from GetNFrames in
-  // getdata where it doesn't belong.
-  int newNF = GetNFrames(_filename.latin1(), &err, 0L) - 2;
-  if (newNF < 0)
+  int newNF;
+
+  newNF = GetNFrames(_filename.latin1(), &err, 0L);
+  if (newNF < 0) {
     newNF = 0;
+  }
   bool isnew = newNF != _frameCount;
 
   _frameCount = newNF;
 
   updateNumFramesScalar();
+
   return setLastUpdateResult(isnew ? KstObject::UPDATE : KstObject::NO_CHANGE);
 }
 
@@ -279,4 +294,3 @@ QStringList fieldList_dirfile(KConfig*, const QString& filename, const QString&
 
 KST_KEY_DATASOURCE_PLUGIN(dirfile)
 
-// vim: ts=2 sw=2 et
