@@ -134,7 +134,7 @@ bool PLANCKIDEFSource::isValidFilename( const QString& filename, Config *config
       //  dd = two digits coding the start timeline day
       //
 
-      unsigned checkLength = gzLength + 25;
+      unsigned checkLength = gzLength + strlen("Accc-xxxx-T-yyyymmdd.fits");
       if( filename.length() >= checkLength )
       {
         QString tail = filename.right( checkLength );
@@ -175,7 +175,7 @@ bool PLANCKIDEFSource::isValidFilename( const QString& filename, Config *config
       //  dd = two digits coding the start timeline day
       //
 
-      unsigned checkLength = gzLength + 19;
+      unsigned checkLength = gzLength + strlen("-xxxx-yyyymmdd.fits");
       if( filename.length() >= checkLength )
       {
         QString tail = filename.right( checkLength );
@@ -198,46 +198,6 @@ bool PLANCKIDEFSource::isValidFilename( const QString& filename, Config *config
         }
       }
     }
-
-    if( !ok )
-    {
-      //
-      // check for a previosuly valid definition of the filename...
-      //
-      // *_yyyymmddhhmm_vv.fits
-      //  yyyy = four digits coding the start timeline year
-      //  mm = two digits coding the start timeline month
-      //  dd = two digits coding the start timeline day
-      //  hh = two digits coding the start timeline hour
-      //  mm = two digits coding the start timeline minute
-      //  vv = version number (to be used in case of regeneration of HK timelines, starting from 00)
-      //
-
-      unsigned checkLength = gzLength + 21;
-      if( filename.length() >= checkLength )
-      {
-        QString tail = filename.right( checkLength );
-        int year;
-        int month;
-        int day;
-        int hour;
-        int minute;
-        int version;
-
-        if( sscanf( tail.latin1(), "_%4d%2d%2d%2d%2d_%2d.fits", 
-            &year, &month, &day, &hour, &minute, &version ) == 6 )        
-        {
-          if( year > 0      &&
-              month >= 1    &&
-              month <= 12   &&
-              day >= 1      &&
-              day <= 31     )
-          {
-            ok = true;
-          }
-        }
-      }
-    }
   }
   else
   {
@@ -247,26 +207,108 @@ bool PLANCKIDEFSource::isValidFilename( const QString& filename, Config *config
   return ok;
 }
 
+QString PLANCKIDEFSource::baseFilenameWithOperationalDay( const QString& filename )
+{
+  QString base;
+  QString baseWithOD;
+  QString operationalDay;
+  int lengthOD;
+
+  lengthOD = strlen("_xxxx");
+  base = baseFilename( filename );
+  if( !base.isEmpty() )
+  {
+    if( filename.length() >= base.length() + lengthOD )
+    {
+      int iOperationalDay = 0;
+
+      operationalDay = filename.mid( base.length(), lengthOD );
+
+      if( sscanf( operationalDay.latin1(), "_%04d", &iOperationalDay ) == 1 ||
+          sscanf( operationalDay.latin1(), "-%04d", &iOperationalDay ) == 1 )
+      {
+        baseWithOD = base + operationalDay;
+      }
+    }
+  }
+
+  return baseWithOD;
+}
 
 QString PLANCKIDEFSource::baseFilename( const QString& filename )
 {
   QString base;
-  unsigned minLength = 14;
+  unsigned gzLength = 0;
+  bool ok = false;
 
   if( filename.right( 3 ).lower( ) == ".gz" ) 
   {
-    minLength += 3;
+    gzLength = 3;
   }
 
-  //
-  // -yyyymmdd.fits
-  //  yyyy = four digits coding the start timeline year
-  //  mm = two digits coding the start timeline month
-  //  dd = two digits coding the start timeline day
-  //
-  if( filename.length() > minLength )
+  if( !ok )
   {
-    base = filename.left( filename.length() - minLength );
+    //
+    // check for a valid science timeline file...
+    //
+    // Accc-xxxx-T-yyyymmdd.fits
+    //  A = one character coding the instrument identifier
+    //  ccc = three character coding the obervation frequency
+    //  xxxx = four digits identifying the operational day to which the data belong
+    //  T = {C,R} one letter identifying if the timeline is converted or reduced
+    //  yyyy = four digits coding the start timeline year
+    //  mm = two digits coding the start timeline month
+    //  dd = two digits coding the start timeline day
+    //
+
+    unsigned minLength = gzLength + strlen("-xxxx-T-yyyymmdd.fits");
+    if( filename.length() >= minLength )
+    {
+      QString tail = filename.right( minLength );
+      char timeline;
+      int operationalDay;
+      int year;
+      int month;
+      int day;
+
+      if( sscanf( tail.latin1(), "-%4d-%c-%4d%2d%2d.fits", 
+        &operationalDay, &timeline, &year, &month, &day ) == 5 )
+      {
+        base = filename.left( filename.length() - minLength );
+        ok = true;
+      }
+    }
+  }
+
+  if( !ok )
+  {
+    //
+    // check for a valid HK timeline file...
+    //
+    // A-namefile-xxxx-yyyymmdd.fits
+    //  A = one character coding the instrument identifier
+    //  xxxx = four digits identifying the operational day to which the data belong
+    //  yyyy = four digits coding the start timeline year
+    //  mm = two digits coding the start timeline month
+    //  dd = two digits coding the start timeline day
+    //
+
+    unsigned minLength = gzLength + strlen("-xxxx-yyyymmdd.fits");
+    if( filename.length() >= minLength )
+    {
+      QString tail = filename.right( minLength );
+      int operationalDay;
+      int year;
+      int month;
+      int day;
+
+      if( sscanf( tail.latin1(), "-%4d-%4d%2d%2d.fits", 
+        &operationalDay, &year, &month, &day ) == 4 )
+      {
+        base = filename.left( filename.length() - minLength );
+        ok = true;
+      }
+    }
   }
 
   return base;
@@ -279,6 +321,24 @@ bool PLANCKIDEFSource::reset( )
 }
 
 
+QString PLANCKIDEFSource::units( const QString& fieldName )
+{
+  QString strUnits;
+
+  if( !fieldName.isEmpty() )
+  {
+    field *fld = 0L;
+
+    fld = _fields.find( fieldName );
+    if( fld != 0L )
+    {
+      strUnits = fld->units;
+    }
+  }
+
+  return strUnits;
+}
+
 void PLANCKIDEFSource::addToMetadata( fitsfile *ffits, int &iStatus )
 {
   int iResult;
@@ -337,6 +397,14 @@ void PLANCKIDEFSource::addToFieldList( fitsfile *ffits, const int iNumCols, int
   QString str;
   char charTemplate[ FLEN_CARD ];
   char charName[ FLEN_CARD ];
+  char headerName[ FLEN_CARD ];
+  char units[ FLEN_CARD ];
+  char ttype[ FLEN_CARD ];
+  char dtype[ FLEN_CARD ];
+  char disp[ FLEN_CARD ];
+  double dScale;
+  double dZero;
+  long lNull;
   long lRepeat;
   long lWidth;
   int iHDUNumber;
@@ -348,6 +416,9 @@ void PLANCKIDEFSource::addToFieldList( fitsfile *ffits, const int iNumCols, int
 
   table = fits_get_hdu_num( ffits, &iHDUNumber );
 
+  iResult = fits_read_key_str( ffits, "EXTNAME", headerName, NULL, &iStatus );
+  iStatus = 0;
+
   for( col=0; col<iNumCols; col++ )
   {
     iResult = fits_get_coltype( ffits, col+1, &iTypeCode, &lRepeat, &lWidth, &iStatus );
@@ -361,9 +432,66 @@ void PLANCKIDEFSource::addToFieldList( fitsfile *ffits, const int iNumCols, int
         {
           field *fld = new field;
 
-          str = QString( "%1_%2" ).arg( charName ).arg( iHDUNumber-1 );
+          str = QString( "%1" ).arg( charName );
+
+          //
+          // the following block is temporary, and required
+          //  as HFI is not yet following the IDEF protocol...
+          //
+
+          {
+            QString strHeader = headerName;
+            int iSequence;
+
+            if( sscanf( headerName, "HFI_%02d_", &iSequence ) == 1 )
+            {
+              int iFound = 0;
+              int foundIndex = 0;
+
+              strHeader.remove( 0, strlen( "HFI_nn_" ) );
+              while( foundIndex < 3 )
+              {
+                iFound--;
+                iFound = strHeader.findRev( '_', iFound );
+                if( iFound == -1 )
+                {
+                  break;
+                }
+                else
+                {
+                  foundIndex++;
+                }
+              }
+
+              if( foundIndex == 3 && iFound != -1 )
+              {
+                strHeader = strHeader.left( iFound );
+              }
+
+              strHeader.replace( '_', '-' );
+
+              str = strHeader;
+            }
+          }
+
+          iResult = fits_get_bcolparms( ffits, col+1, ttype, units, dtype, &lRepeat, &dScale, &dZero, &lNull, disp, &iStatus );
+
+          if( _fields.find( str ) != 0 )
+          {
+            str = QString( "%1_%2" ).arg( charName ).arg( headerName );
+          }
+
+          if( _fields.find( str ) != 0 )
+          {
+            str = QString( "%1_%2" ).arg( charName ).arg( iHDUNumber-1 );
+          }
 
           fld->basefile = QString("");
+          if( iResult == 0 ) {
+            fld->units = units;
+          } else {
+            fld->units = QString::null;
+          }
           fld->table = table;
           fld->column = iColNumber;
 
@@ -381,6 +509,13 @@ void PLANCKIDEFSource::addToFieldList( fitsfile *ffits, const QString& prefix, c
   QString str;
   char charTemplate[ FLEN_CARD ];
   char charName[ FLEN_CARD ];
+  char ttype[ FLEN_CARD ];
+  char dtype[ FLEN_CARD ];
+  char disp[ FLEN_CARD ];
+  char units[ FLEN_CARD ];
+  double dScale;
+  double dZero;
+  long lNull;
   long lRepeat;
   long lWidth;
   int iHDUNumber;
@@ -405,9 +540,13 @@ void PLANCKIDEFSource::addToFieldList( fitsfile *ffits, const QString& prefix, c
         {
           field *fld = new field;
 
-          if( prefix.isEmpty() )
+          if( prefix.isEmpty( ) )
           {
-            str = QString( "%1_%2" ).arg( charName ).arg( iHDUNumber-1 );
+            str = QString( "%1" ).arg( charName );
+            if( _fields.find( str ) != 0 )
+            {
+              str = QString( "%1_%2" ).arg( charName ).arg( iHDUNumber-1 );
+            }
           }
           else
           {
@@ -418,7 +557,14 @@ void PLANCKIDEFSource::addToFieldList( fitsfile *ffits, const QString& prefix, c
             }
           }
 
+          iResult = fits_get_bcolparms( ffits, col+1, ttype, units, dtype, &lRepeat, &dScale, &dZero, &lNull, disp, &iStatus );
+
           fld->basefile = baseName;
+          if( iResult == 0 ) {
+            fld->units = units;
+          } else {
+            fld->units = QString::null;
+          }
           fld->table = table;
           fld->column = iColNumber;
 
@@ -667,10 +813,10 @@ bool PLANCKIDEFSource::initFolderFile( const QString& filename, const QString& p
 
 bool PLANCKIDEFSource::initFolder( )
 {
-  QDir        folder( _filename, "*.fits *.fits.gz", QDir::Name | QDir::IgnoreCase, QDir::Files | QDir::Readable );
-  QStringList files;
-  QStringList filesBase;
-  bool        bRetVal = true;
+  QDir            folder( _filename, "*.fits *.fits.gz", QDir::Name | QDir::IgnoreCase, QDir::Files | QDir::Readable );
+  QStringList     files;
+  QDict<QString>  filesBaseWithOD;
+  bool            bRetVal = true;
 
   _basefiles.setAutoDelete(false);
 
@@ -684,6 +830,7 @@ bool PLANCKIDEFSource::initFolder( )
         fileList*   folderFields;
         folderField folderField;
         QString     baseName = baseFilename(*it);
+        QString     baseNameWithOD = baseFilenameWithOperationalDay(*it);
         QString     pathname = folder.path() + separator() + *it;
         int         numFrames;
 
@@ -701,6 +848,7 @@ bool PLANCKIDEFSource::initFolder( )
             field *fld = new field;
 
             fld->basefile = baseName;
+            fld->units = QString::null;
             fld->table = 0;
             fld->column = 0;
 
@@ -718,6 +866,10 @@ bool PLANCKIDEFSource::initFolder( )
             folderFieldsNew->append( folderField );
 
             _basefiles.replace( baseName, folderFieldsNew );
+            if( !baseNameWithOD.isEmpty() )
+            {
+              filesBaseWithOD.replace( baseNameWithOD, &baseNameWithOD );
+            }
           }
         }
         else
@@ -729,7 +881,23 @@ bool PLANCKIDEFSource::initFolder( )
             folderField.frames   = numFrames;
             folderField.file     = pathname;
 
-            folderFields->append( folderField );
+            //
+            // we might simply have found the same file produced at a later date.
+            //  In this case we want to simply wipe out the older version...
+            //
+
+            if( !baseNameWithOD.isEmpty() && filesBaseWithOD.find( baseNameWithOD ) )
+            {
+              if( !folderFields->empty( ) )
+              {
+                folderFields->pop_back( );
+              }
+              folderFields->append( folderField );
+            }
+            else
+            {
+              folderFields->append( folderField );
+            }
           }
         }
       }
@@ -1300,6 +1468,186 @@ bool PLANCKIDEFSource::setConfiguration(QString setting, const QString &value) {
 }
 
 
+bool PLANCKIDEFSource::supportsTimeConversions() const {
+  return _fieldList.contains("OBT");
+}
+
+
+int PLANCKIDEFSource::sampleForOBT(double timeIDEF, bool *ok) {
+  double    value;
+  int       indexLo = 0;
+  int       indexHi = _numFrames-1;
+  int       index;
+  int       sample = -1;
+
+  while( indexHi > indexLo )
+  {
+    index = ( indexLo + indexHi ) / 2;
+    if( readField( &value, "OBT", index, 1 ) == 1 )
+    {
+      if( value == timeIDEF )
+      {
+        sample = index;
+
+        if (ok)
+        {
+          *ok = true;
+        }
+
+        break;
+      }
+      else if( value > timeIDEF )
+      {
+        indexHi = index;
+      }
+      else
+      {
+        indexLo = index;
+      }
+
+      if( ( indexLo + indexHi ) / 2 == indexLo )
+      {
+        sample = indexLo;
+
+        if (ok)
+        {
+          *ok = true;
+        }
+
+        break;
+      }
+    }
+    else
+    {
+      break;
+    }
+  }
+
+  return sample;
+}
+
+
+int PLANCKIDEFSource::sampleForTime(const KST::ExtDateTime& time, bool *ok) {
+  int sample = -1;
+
+  if (!_valid)
+  {
+    if (ok)
+    {
+      *ok = false;
+    }
+
+    return sample;
+  }
+
+  double timeIDEF;
+
+  //
+  // need to convert from KST::ExtDateTime to IDEF OBT (TAI in 2^-16 seconds)...
+  //
+  timeIDEF = 65536.0 * ( extDateTimeUTCToTime_t(time) + ( 86400.0 * ( 365.0 * 12.0 + 3.0 ) ) );
+  sample = sampleForOBT( timeIDEF, ok );
+
+  return sample;
+}
+
+
+int PLANCKIDEFSource::sampleForTime(double ms, bool *ok) {
+  int sample = -1;
+
+  if (!_valid)
+  {
+    if (ok)
+    {
+      *ok = false;
+    }
+
+    return sample;
+  }
+
+  double timeZero;
+
+  if( readField( &timeZero, "OBT", 0, 1 ) == 1 )
+  {
+    double timeIDEF;
+
+    //
+    // need to convert from ms time to TAI in 2^-16 seconds...
+    //
+    timeIDEF = timeZero + ( ms * 65.536 );
+
+    sample = sampleForOBT( timeIDEF, ok );
+  }
+
+  return sample;
+}
+
+
+KST::ExtDateTime PLANCKIDEFSource::timeForSample(int sample, bool *ok) {
+  KST::ExtDateTime t;
+
+  if (!_valid)
+  {
+    if (ok)
+    {
+      *ok = false;
+    }
+
+    return t;
+  }
+
+  double time;
+
+  if( readField( &time, "OBT", sample, 1 ) == 1 )
+  {
+    if( time == time )
+    {
+      t.setTime_t( (int)((time / 65536.0) - ( 86400.0 * (365.0 * 12.0 + 3.0))));
+
+      if (ok)
+      {
+        *ok = true;
+      }
+    }
+  }
+
+  return t;
+}
+
+
+double PLANCKIDEFSource::relativeTimeForSample(int sample, bool *ok) {
+  double timeRelativeMS = -1.0;
+
+  if (!_valid)
+  {
+    if (ok)
+    {
+      *ok = false;
+    }
+
+    return timeRelativeMS;
+  }
+
+  double value;
+  double valueZero;
+
+  if( readField( &valueZero, "OBT", 0, 1 ) == 1 )
+  {
+    if( readField( &value, "OBT", sample, 1 ) == 1 )
+    {
+      timeRelativeMS = ( value - valueZero ) / 65.536;
+
+      if (ok)
+      {
+        *ok = true;
+      }
+    }
+  }
+
+  return timeRelativeMS;
+}
+
+
 class ConfigWidgetPlanckIDEF : public KstDataSourceConfigWidget {
   public:
     ConfigWidgetPlanckIDEF() : KstDataSourceConfigWidget() {
@@ -1349,6 +1697,13 @@ extern "C" {
     return rc;
   }
 
+  bool supportsTime_planckIDEF(KConfig*, const QString& filename) 
+  {
+    Q_UNUSED(filename);
+
+    return true;
+  }
+
   bool supportsHierarchy_planckIDEF( )
   {
     return true;
