@@ -383,9 +383,9 @@ KJS::Value KstBindAxis::offsetMode(KJS::ExecState *exec) const {
   }
   KstReadLocker rl(_d);
   if (_xAxis) {
-    return KJS::Boolean(_d->xOffsetMode());
+    return KJS::Number(_d->xOffsetMode());
   } else {
-    return KJS::Boolean(_d->yOffsetMode());
+    return KJS::Number(_d->yOffsetMode());
   }
 }
 
@@ -394,16 +394,52 @@ void KstBindAxis::setOffsetMode(KJS::ExecState *exec, const KJS::Value& value) {
   if (!_d) {
     return createPropertyInternalError(exec);
   }
-  if (value.type() != KJS::BooleanType) {
+
+  if (value.type() != KJS::BooleanType &&
+      value.type() != KJS::NumberType) {
     return createPropertyTypeError(exec);
   }
+
   KstWriteLocker wl(_d);
-  if (_xAxis) {
-    _d->setXOffsetMode(value.toBoolean(exec));
+
+  if (value.type() == KJS::BooleanType) {
+    if (_xAxis) {
+      if (value.toBoolean(exec)) {
+        _d->setXOffsetMode(OFFSET_ON);
+      } else {
+        _d->setXOffsetMode(OFFSET_AUTO);
+      }
+    } else {
+      if (value.toBoolean(exec)) {
+        _d->setYOffsetMode(OFFSET_ON);
+      } else {
+        _d->setYOffsetMode(OFFSET_AUTO);
+      }
+    }
   } else {
-    _d->setYOffsetMode(value.toBoolean(exec));
+    int iOffset;
+    KstOffsetType offset;
+
+    iOffset = value.toInt32(exec);
+    if (iOffset == OFFSET_AUTO) {
+      offset = OFFSET_AUTO;
+    } else if (iOffset == OFFSET_ON) {
+      offset = OFFSET_ON;
+    } else if (iOffset == OFFSET_OFF) {
+      offset = OFFSET_OFF;
+    } else {
+      return createPropertyRangeError(exec);
+    }
+
+    if (_xAxis) {
+      _d->setXOffsetMode(offset);
+    } else {
+      _d->setYOffsetMode(offset);
+    }
   }
+
   _d->setDirty();
+
   KstApp::inst()->paintAll(KstPainter::P_PAINT);
 }
 
@@ -676,9 +712,9 @@ void KstBindAxis::setMajorTickDensity(KJS::ExecState *exec, const KJS::Value& va
 
   KstWriteLocker rl(_d);
   if (_xAxis) {
-    _d->setXMajorTicks(value.toInt32(exec));
+    _d->setXMajorTicks(i);
   } else {
-    _d->setYMajorTicks(value.toInt32(exec));
+    _d->setYMajorTicks(i);
   }
   _d->setDirty();
   KstApp::inst()->paintAll(KstPainter::P_PAINT);
