@@ -55,6 +55,12 @@ class KstBindCSD : public KstBindDataObject {
     KJS::ReferenceList propList(KJS::ExecState *exec, bool recursive = true);
     bool hasProperty(KJS::ExecState *exec, const KJS::Identifier& propertyName) const;
 
+    /* @property Vector vector
+       @description The input vector for the spectrogram.
+    */
+    void setVector(KJS::ExecState *exec, const KJS::Value& value);
+    KJS::Value vector(KJS::ExecState *exec) const;
+
     /* @property number length
        @description Contains the base 2 logarithm of the length of the spectrogram.  
                     Should be an integer &gt;= 4.
