@@ -17,6 +17,7 @@
 
 #include "bind_curve.h"
 #include "bind_point.h"
+#include "bind_scalar.h"
 #include "bind_vector.h"
 
 #include <ksthistogram.h>
@@ -187,6 +188,7 @@ static CurveProperties curveProperties[] = {
   { "yErrorVector", &KstBindCurve::setYErrorVector, &KstBindCurve::yErrorVector },
   { "xMinusErrorVector", &KstBindCurve::setXMinusErrorVector, &KstBindCurve::xMinusErrorVector },
   { "yMinusErrorVector", &KstBindCurve::setYMinusErrorVector, &KstBindCurve::yMinusErrorVector },
+  { "yVectorOffset", &KstBindCurve::setYVectorOffset, &KstBindCurve::yVectorOffset },
   { "samplesPerFrame", 0L, &KstBindCurve::samplesPerFrame },
   { "ignoreAutoScale", &KstBindCurve::setIgnoreAutoScale, &KstBindCurve::ignoreAutoScale },
   { "hasPoints", &KstBindCurve::setHasPoints, &KstBindCurve::hasPoints },
@@ -631,6 +633,43 @@ KJS::Value KstBindCurve::yMinusErrorVector(KJS::ExecState *exec) const {
 }
 
 
+void KstBindCurve::setYVectorOffset(KJS::ExecState *exec, const KJS::Value& value) {
+  KstScalarPtr sp = extractScalar(exec, value, false);
+  if (sp) {
+    KstVCurvePtr d = makeCurve(_d);
+    if (d) {
+      KstWriteLocker wl(d);
+      d->setYVectorOffsetScalar(sp);
+      d->setYVectorOffset(true);
+    }
+  } else if (value.toString(exec).qstring().stripWhiteSpace().isEmpty()) {
+    KstVCurvePtr d = makeCurve(_d);
+    if (d) {
+      KstWriteLocker wl(d);
+      d->setYVectorOffsetScalar(sp);
+      d->setYVectorOffset(false);
+    }
+  } else {
+    return createPropertyTypeError(exec);
+  }
+}
+
+
+KJS::Value KstBindCurve::yVectorOffset(KJS::ExecState *exec) const {
+  KstVCurvePtr d = makeCurve(_d);
+  if (d) {
+    KstReadLocker rl(d);
+    if (d->yVectorOffset()) {
+      KstScalarPtr sp = d->yVectorOffsetScalar();
+      if (sp) {
+        return KJS::Object(new KstBindScalar(exec, sp));
+      }
+    }
+  }
+  return KJS::Null();
+}
+
+
 KJS::Value KstBindCurve::samplesPerFrame(KJS::ExecState *exec) const {
   Q_UNUSED(exec)
   KstVCurvePtr d = makeCurve(_d);
