@@ -109,6 +109,13 @@ class KstBindDataSource : public KstBindObject {
     */
     KJS::Value configuration(KJS::ExecState *exec, const KJS::List& args);
 
+    /* @method units
+       @arg string field Gives the field name to retrieve the units of.
+       @returns string
+       @description Gets the units associated with a field of the data source.
+    */
+    KJS::Value units(KJS::ExecState *exec, const KJS::List& args);
+
     // properties
 
     /* @property boolean valid
