@@ -20,6 +20,7 @@
 
 #include <kstdatasource.h>
 #include <kstdatacollection.h>
+#include <timedefinitions.h>
 
 #include <kdebug.h>
 
@@ -51,7 +52,89 @@ inline int d2i(double x) {
 }
 
 
+KJS::Object KstBindDataVector::constructAlternate(KJS::ExecState *exec, const KJS::List& args) {
+  KstRVectorPtr v;
+  KstDataSourcePtr dp = extractDataSource(exec, args[0]);
+  QString field;
+
+  if (dp) {
+    if (!dp->supportsTimeConversions()) {
+      return createGeneralError(exec, i18n("Data source %1 does not understand time.").arg(dp->fileName()));
+    }
+  } else {
+    return createTypeError(exec, 0);
+  }
+
+  if (args[1].type() != KJS::StringType) {
+    return createTypeError(exec, 1);
+  }
+
+  field = args[1].toString(exec).qstring();
+
+  // construct() already handles the case where we have only two arguments...
+
+  if (args.size() >= 6) {
+    if (args[2].type() != KJS::StringType) {
+      return createTypeError(exec, 2);
+    } else if (args[3].type() != KJS::NumberType && args[3].type() != KJS::StringType) {
+      return createTypeError(exec, 3);
+    } else if (args[4].type() != KJS::StringType) {
+      return createTypeError(exec, 4);
+    } else if (args[5].type() != KJS::NumberType) {
+      return createTypeError(exec, 5);
+    }
+
+    int start = 0;
+    int count = -1;
+    bool ok = false;
+
+    KJS::Object check = retrieveStartCount( dp, exec, args, 2, start, count, ok );
+    if (!ok) {
+      return check;
+    }
+
+    if (args.size() == 6) {
+      v = new KstRVector(dp, field, KstObjectTag::invalidTag, start, count, -1, false, false);
+    }
+
+    if (args.size() == 7) {
+      if (args[6].type() != KJS::NumberType) {
+        return createTypeError(exec, 6);
+      }
+
+      int skip = d2i(args[6].toNumber(exec));
+
+      v = new KstRVector(dp, field, KstObjectTag::invalidTag, start, count, skip, true, false);
+    }
+
+    // Constructor: DataVector(DataSource, field, start, n, skip, ave)
+    if (args.size() == 8) {
+      if (args[6].type() != KJS::NumberType) {
+        return createTypeError(exec, 6);
+      } else if (args[7].type() != KJS::BooleanType) {
+        return createTypeError(exec, 7);
+      }
+
+      int skip = d2i(args[6].toNumber(exec));
+      bool ave = args[7].toBoolean(exec);
+
+      v = new KstRVector(dp, field, KstObjectTag::invalidTag, start, count, skip, true, ave);
+    }
+  }
+
+  if (!v) {
+    return createSyntaxError(exec);
+  }
+
+  return KJS::Object(new KstBindDataVector(exec, v));
+}
+
+
 KJS::Object KstBindDataVector::construct(KJS::ExecState *exec, const KJS::List& args) {
+  if (args.size() >= 6 && args[2].type() == KJS::StringType) {
+    return constructAlternate(exec, args);
+  }
+
   KstRVectorPtr v;
   KstDataSourcePtr dp = extractDataSource(exec, args[0]);
 
@@ -121,7 +204,7 @@ KJS::Object KstBindDataVector::construct(KJS::ExecState *exec, const KJS::List&
     int start = d2i(args[2].toNumber(exec));
     int count = d2i(args[3].toNumber(exec));
     int skip = d2i(args[4].toNumber(exec));
-    bool ave = d2i(args[5].toBoolean(exec));
+    bool ave = args[5].toBoolean(exec);
 
     v = new KstRVector(dp, field, KstObjectTag::invalidTag, start, count, skip, true, ave);
   }
@@ -150,6 +233,7 @@ struct DataVectorProperties {
 static DataVectorBindings dataVectorBindings[] = {
   { "changeFile", &KstBindDataVector::changeFile },
   { "changeFrames", &KstBindDataVector::changeFrames },
+  { "changeFramesByTime", &KstBindDataVector::changeFramesByTime },
   { "reload", &KstBindDataVector::reload },
   { 0L, 0L }
 };
@@ -359,6 +443,68 @@ KJS::Value KstBindDataVector::changeFrames(KJS::ExecState *exec, const KJS::List
 }
 
 
+KJS::Value KstBindDataVector::changeFramesByTime(KJS::ExecState *exec, const KJS::List& args) {
+  KstRVectorPtr v = makeDataVector(_d);
+  if (!v) {
+    return createInternalError(exec);
+  }
+
+  KstDataSourcePtr dp = v->dataSource();
+  if (dp) {
+    if (!dp->supportsTimeConversions()) {
+      return createGeneralError(exec, i18n("Data source %1 does not understand time.").arg(dp->fileName()));
+    }
+  }
+
+  if (args.size() > 3) {
+    if (args[0].type() != KJS::StringType) {
+      return createTypeError(exec, 0);
+    } else if (args[1].type() != KJS::NumberType && args[1].type() != KJS::StringType) {
+      return createTypeError(exec, 1);
+    } else if (args[2].type() != KJS::StringType) {
+      return createTypeError(exec, 2);
+    } else if (args[3].type() != KJS::NumberType) {
+      return createTypeError(exec, 3);
+    }
+
+    int start = 0;
+    int count = -1;
+    bool ok = false;
+
+    KJS::Object check = retrieveStartCount( dp, exec, args, 0, start, count, ok );
+    if (!ok) {
+      return check;
+    }
+
+    KstWriteLocker wl(v);
+    int skip = v->doSkip() ? v->skip() : -1;
+    bool ave = v->doAve();
+
+    if (args.size() > 4) {
+      if (args[4].type() != KJS::NumberType) {
+        return createTypeError(exec, 4);
+      }
+
+      skip = d2i(args[4].toNumber(exec));
+
+      if (args.size() > 5) {
+        if (args[5].type() != KJS::BooleanType) {
+          return createTypeError(exec, 5);
+        }
+
+        ave = args[5].toBoolean(exec);
+      }
+    }
+
+    v->changeFrames(start, count, skip, skip >= 0, ave);
+
+    return KJS::Undefined();
+  }
+
+  return createSyntaxError(exec);
+}
+
+
 KJS::Value KstBindDataVector::valid(KJS::ExecState *exec) const {
   Q_UNUSED(exec)
   KstRVectorPtr v = makeDataVector(_d);
@@ -466,5 +612,79 @@ KJS::Value KstBindDataVector::dataSource(KJS::ExecState *exec) const {
   return KJS::Object(new KstBindDataSource(exec, dp));
 }
 
+
+KJS::Object KstBindDataVector::retrieveStartCount( KstDataSourcePtr dp, KJS::ExecState *exec, const KJS::List& args, int indexOffset, int &start, int &count, bool &okMain )
+{
+  QString startType = args[0+indexOffset].toString(exec).qstring().lower();
+  QString countType = args[2+indexOffset].toString(exec).qstring().lower();
+  bool ok;
+  int startIndex = -1;
+  int countIndex = -1;
+  int index;
+
+  okMain = false;
+
+  for (index=0; index<(int)(sizeof(KST::timeDefinitions)/sizeof(KstTimeDef)); ++index) {
+    if (QString::compare(startType,KST::timeDefinitions[index].name) == 0) {
+      startIndex = index;
+
+      break;
+    }
+  }
+
+  if (startIndex == -1) {
+    return createTypeError(exec, 0);
+  }
+
+  for (index=0; index<(int)(sizeof(KST::timeDefinitions)/sizeof(KstTimeDef)); ++index) {
+    if (index != KST::dateTimeEntry) {
+      if (QString::compare(countType,KST::timeDefinitions[index].name) == 0) {
+        countIndex = index;
+
+        break;
+      }
+    }
+  }
+
+  if (countIndex == -1) {
+    return createTypeError(exec, 2);
+  }
+
+  if (startIndex == KST::dateTimeEntry) {
+    if (args[1+indexOffset].type() != KJS::StringType) {
+      return createTypeError(exec, 1);
+    }
+    KST::ExtDateTime edt = KST::parsePlanckDate(args[1+indexOffset].toString(exec).qstring(), false);
+    if (edt.isNull()) {
+      return createTypeError(exec, 1);
+    }
+    start = dp->sampleForTime(edt, &ok);
+  } else if (countIndex > KST::dateTimeEntry) {
+    if (args[1+indexOffset].type() != KJS::NumberType) {
+      return createTypeError(exec, 1);
+    }
+    start = dp->sampleForTime(args[1+indexOffset].toNumber(exec) * KST::timeDefinitions[startIndex].factor, &ok);
+  } else {
+    if (args[1+indexOffset].type() != KJS::NumberType) {
+      return createTypeError(exec, 1);
+    }
+    start = d2i(args[1+indexOffset].toNumber(exec));
+  }
+
+  if (countIndex > KST::dateTimeEntry) {
+    double timeRelative = dp->relativeTimeForSample(start);
+    double timeRange = args[3+indexOffset].toNumber(exec) * KST::timeDefinitions[countIndex].factor;
+    count = dp->sampleForTime(timeRelative + timeRange, &ok) - start;
+  } else {
+    count = d2i(args[3+indexOffset].toNumber(exec));
+  }
+
+  okMain = true;
+
+  return KJS::Object();
+}
+
+
+
 #undef makeDataVector
 
