@@ -60,9 +60,7 @@ KstBindEllipse::~KstBindEllipse() {
 
 KJS::Object KstBindEllipse::construct(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, "Requires exactly one argument.");
-    exec->setException(eobj);
-    return KJS::Object();
+    return createSyntaxError(exec);
   }
 
   KstViewObjectPtr view = extractViewObject(exec, args[0]);
@@ -71,9 +69,7 @@ KJS::Object KstBindEllipse::construct(KJS::ExecState *exec, const KJS::List& arg
     if (w) {
       view = w->view();
     } else {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+      return createTypeError(exec, 0);
     }
   }
 
@@ -177,7 +173,7 @@ KJS::Value KstBindEllipse::get(KJS::ExecState *exec, const KJS::Identifier& prop
       return (this->*ellipseProperties[i].get)(exec);
     }
   }
-  
+
   return KstBindViewObject::get(exec, propertyName);
 }
 
@@ -185,18 +181,14 @@ KJS::Value KstBindEllipse::get(KJS::ExecState *exec, const KJS::Identifier& prop
 KJS::Value KstBindEllipse::call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args) {
   int id = this->id();
   if (id <= 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   int start = KstBindViewObject::methodCount();
   if (id > start) {
     KstBindEllipse *imp = dynamic_cast<KstBindEllipse*>(self.imp());
     if (!imp) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-      exec->setException(eobj);
-      return KJS::Undefined();
+      return createInternalError(exec);
     }
 
     return (imp->*ellipseBindings[id - start - 1].method)(exec, args);
@@ -220,9 +212,7 @@ void KstBindEllipse::addBindings(KJS::ExecState *exec, KJS::Object& obj) {
 void KstBindEllipse::setBorderColor(KJS::ExecState *exec, const KJS::Value& value) {
   QVariant cv = KJSEmbed::convertToVariant(exec, value);
   if (!cv.canCast(QVariant::Color)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstViewEllipsePtr d = makeEllipse(_d);
   if (d) {
@@ -246,9 +236,7 @@ KJS::Value KstBindEllipse::borderColor(KJS::ExecState *exec) const {
 void KstBindEllipse::setBorderWidth(KJS::ExecState *exec, const KJS::Value& value) {
   unsigned w = 0;
   if (value.type() != KJS::NumberType || !value.toUInt32(w)) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstViewEllipsePtr d = makeEllipse(_d);
   if (d) {
