@@ -71,22 +71,16 @@ KJS::Object KstBindPlot::construct(KJS::ExecState *exec, const KJS::List& args)
   if (args.size() == 1) {
     w = extractWindow(exec, args[0]);
     if (!w) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Object();
+      return createTypeError(exec, 0);
     }
   } else {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Object();
+    return createSyntaxError(exec);
   }
 
   QString n = w->createPlotObject(KST::suggestPlotName(), false);
   Kst2DPlotPtr p = *w->view()->findChildrenType<Kst2DPlot>(true).findTag(n);
   if (!p) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Object();
+    return createGeneralError(exec, i18n("Failed to create plot."));
   }
 
   w->view()->paint(KstPainter::P_PAINT);
@@ -184,7 +178,7 @@ KJS::Value KstBindPlot::get(KJS::ExecState *exec, const KJS::Identifier& propert
       return (this->*plotProperties[i].get)(exec);
     }
   }
-  
+
   return KstBindBorderedViewObject::get(exec, propertyName);
 }
 
@@ -192,18 +186,14 @@ KJS::Value KstBindPlot::get(KJS::ExecState *exec, const KJS::Identifier& propert
 KJS::Value KstBindPlot::call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args) {
   int id = this->id();
   if (id <= 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   int start = KstBindBorderedViewObject::methodCount();
   if (id > start) {
     KstBindPlot *imp = dynamic_cast<KstBindPlot*>(self.imp());
     if (!imp) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-      exec->setException(eobj);
-      return KJS::Undefined();
+      return createInternalError(exec);
     }
     return (imp->*plotBindings[id - start - 1].method)(exec, args);
   }
@@ -258,9 +248,7 @@ KJS::Value KstBindPlot::legend(KJS::ExecState *exec) const {
 
 void KstBindPlot::setTopLabel(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::StringType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   Kst2DPlotPtr d = makePlot(_d);
   if (d) {
@@ -316,15 +304,11 @@ KJS::Value KstBindPlot::title(KJS::ExecState *exec) const {
 KJS::Value KstBindPlot::createLegend(KJS::ExecState *exec, const KJS::List& args) {
   Kst2DPlotPtr d = makePlot(_d);
   if (!d) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   if (args.size() != 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   KstWriteLocker rl(d);
@@ -336,9 +320,7 @@ KJS::Value KstBindPlot::createLegend(KJS::ExecState *exec, const KJS::List& args
 
 void KstBindPlot::setTied(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   Kst2DPlotPtr d = makePlot(_d);
   if (d) {
