@@ -249,6 +249,12 @@ void KstBindVectorView::setXVector(KJS::ExecState *exec, const KJS::Value& value
       KstWriteLocker wl(d);
       d->setXVector(v);
       d->setDirty();
+      d->setRecursed(false);
+      if (d->recursion()) {
+        d->setRecursed(true);
+
+        createGeneralError(exec, i18n("Command resulted in a recursion."));
+      }
     }
   }
 }
@@ -275,6 +281,12 @@ void KstBindVectorView::setYVector(KJS::ExecState *exec, const KJS::Value& value
       KstWriteLocker wl(d);
       d->setYVector(v);
       d->setDirty();
+      d->setRecursed(false);
+      if (d->recursion()) {
+        d->setRecursed(true);
+
+        createGeneralError(exec, i18n("Command resulted in a recursion."));
+      }
     }
   }
 }
