@@ -82,7 +82,7 @@ int KstBinding::id() const {
 }
 
 
-KstDataSourcePtr KstBinding::extractDataSource(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) {
+KstDataSourcePtr KstBinding::extractDataSource(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) const {
   switch (value.type()) {
     case KJS::ObjectType:
       {
@@ -92,8 +92,7 @@ KstDataSourcePtr KstBinding::extractDataSource(KJS::ExecState *exec, const KJS::
           dp = kst_cast<KstDataSource>(imp->_d);
         }
         if (!dp && doThrow) {
-          KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract dataSource.");
-          exec->setException(eobj);
+          createGeneralError(exec, i18n("Failed to extract dataSource."));
         }
         return dp;
       }
@@ -113,15 +112,14 @@ KstDataSourcePtr KstBinding::extractDataSource(KJS::ExecState *exec, const KJS::
       // fall through and throw
     default:
       if (doThrow) {
-        KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract dataSource.");
-        exec->setException(eobj);
+        createGeneralError(exec, i18n("Failed to extract dataSource."));
       }
       return 0L;
   }
 }
 
 
-KstPluginPtr KstBinding::extractPluginModule(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) {
+KstPluginPtr KstBinding::extractPluginModule(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) const {
   switch (value.type()) {
     case KJS::ObjectType:
       {
@@ -135,8 +133,7 @@ KstPluginPtr KstBinding::extractPluginModule(KJS::ExecState *exec, const KJS::Va
         }
 
         if (!dp && doThrow) {
-          KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract plugin.");
-          exec->setException(eobj);
+          createGeneralError(exec, i18n("Failed to extract plugin."));
         }
 
         return dp;
@@ -145,15 +142,14 @@ KstPluginPtr KstBinding::extractPluginModule(KJS::ExecState *exec, const KJS::Va
       // fall through and throw
     default:
       if (doThrow) {
-        KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract plugin.");
-        exec->setException(eobj);
+        createGeneralError(exec, i18n("Failed to extract plugin."));
       }
       return 0L;
   }
 }
 
 
-KstBasicPluginPtr KstBinding::extractBasicPluginModule(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) {
+KstBasicPluginPtr KstBinding::extractBasicPluginModule(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) const {
   switch (value.type()) {
     case KJS::ObjectType:
       {
@@ -168,8 +164,7 @@ KstBasicPluginPtr KstBinding::extractBasicPluginModule(KJS::ExecState *exec, con
         }
 
         if (!bp && doThrow) {
-          KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract basic plugin.");
-          exec->setException(eobj);
+          createGeneralError(exec, i18n("Failed to extract basic plugin."));
         }
 
         return bp;
@@ -178,15 +173,14 @@ KstBasicPluginPtr KstBinding::extractBasicPluginModule(KJS::ExecState *exec, con
       // fall through and throw
     default:
       if (doThrow) {
-        KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract basic plugin.");
-        exec->setException(eobj);
+        createGeneralError(exec, i18n("Failed to extract basic plugin."));
       }
       return 0L;
   }
 }
 
 
-KstDataObjectPtr KstBinding::extractDataObject(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) {
+KstDataObjectPtr KstBinding::extractDataObject(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) const {
   switch (value.type()) {
     case KJS::ObjectType:
       {
@@ -196,8 +190,7 @@ KstDataObjectPtr KstBinding::extractDataObject(KJS::ExecState *exec, const KJS::
           dp = kst_cast<KstDataObject>(imp->_d);
         }
         if (!dp && doThrow) {
-          KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract dataObject.");
-          exec->setException(eobj);
+          createGeneralError(exec, i18n("Failed to extract dataObject."));
         }
         return dp;
       }
@@ -213,15 +206,14 @@ KstDataObjectPtr KstBinding::extractDataObject(KJS::ExecState *exec, const KJS::
       // fall through and throw
     default:
       if (doThrow) {
-        KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract dataObject.");
-        exec->setException(eobj);
+        createGeneralError(exec, i18n("Failed to extract dataObject."));
       }
       return 0L;
   }
 }
 
 
-KstVectorPtr KstBinding::extractVector(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) {
+KstVectorPtr KstBinding::extractVector(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) const {
   switch (value.type()) {
     case KJS::ObjectType:
       {
@@ -236,8 +228,7 @@ KstVectorPtr KstBinding::extractVector(KJS::ExecState *exec, const KJS::Value& v
           }
         }
         if (!vp && doThrow) {
-          KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract vector.");
-          exec->setException(eobj);
+          createGeneralError(exec, i18n("Failed to extract vector."));
         }
         return vp;
       }
@@ -253,15 +244,14 @@ KstVectorPtr KstBinding::extractVector(KJS::ExecState *exec, const KJS::Value& v
       // fall through and throw
     default:
       if (doThrow) {
-        KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract vector.");
-        exec->setException(eobj);
+        createGeneralError(exec, i18n("Failed to extract vector."));
       }
       return 0L;
   }
 }
 
 
-KstScalarPtr KstBinding::extractScalar(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) {
+KstScalarPtr KstBinding::extractScalar(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) const {
   switch (value.type()) {
     case KJS::ObjectType:
       {
@@ -271,8 +261,7 @@ KstScalarPtr KstBinding::extractScalar(KJS::ExecState *exec, const KJS::Value& v
           sp = kst_cast<KstScalar>(imp->_d);
         }
         if (!sp && doThrow) {
-          KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract scalar.");
-          exec->setException(eobj);
+          createGeneralError(exec, i18n("Failed to extract scalar."));
         }
         return sp;
       }
@@ -288,15 +277,14 @@ KstScalarPtr KstBinding::extractScalar(KJS::ExecState *exec, const KJS::Value& v
       // fall through and throw
     default:
       if (doThrow) {
-        KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract scalar.");
-        exec->setException(eobj);
+        createGeneralError(exec, i18n("Failed to extract scalar."));
       }
       return 0L;
   }
 }
 
 
-KstStringPtr KstBinding::extractString(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) {
+KstStringPtr KstBinding::extractString(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) const {
   switch (value.type()) {
     case KJS::ObjectType:
       {
@@ -306,8 +294,7 @@ KstStringPtr KstBinding::extractString(KJS::ExecState *exec, const KJS::Value& v
           sp = kst_cast<KstString>(imp->_d);
         }
         if (!sp && doThrow) {
-          KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract string.");
-          exec->setException(eobj);
+          createGeneralError(exec, i18n("Failed to extract string."));
         }
         return sp;
       }
@@ -323,15 +310,14 @@ KstStringPtr KstBinding::extractString(KJS::ExecState *exec, const KJS::Value& v
       // fall through and throw
     default:
       if (doThrow) {
-        KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract scalar.");
-        exec->setException(eobj);
+        createGeneralError(exec, i18n("Failed to extract string."));
       }
       return 0L;
   }
 }
 
 
-KstVCurvePtr KstBinding::extractVCurve(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) {
+KstVCurvePtr KstBinding::extractVCurve(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) const {
   switch (value.type()) {
     case KJS::ObjectType:
       {
@@ -341,8 +327,7 @@ KstVCurvePtr KstBinding::extractVCurve(KJS::ExecState *exec, const KJS::Value& v
           vp = kst_cast<KstVCurve>(imp->_d);
         }
         if (!vp && doThrow) {
-          KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract curve.");
-          exec->setException(eobj);
+          createGeneralError(exec, i18n("Failed to extract curve."));
         }
         return vp;
       }
@@ -358,15 +343,14 @@ KstVCurvePtr KstBinding::extractVCurve(KJS::ExecState *exec, const KJS::Value& v
       // fall through and throw
     default:
       if (doThrow) {
-        KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract curve.");
-        exec->setException(eobj);
+        createGeneralError(exec, i18n("Failed to extract curve."));
       }
       return 0L;
   }
 }
 
 
-KstMatrixPtr KstBinding::extractMatrix(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) {
+KstMatrixPtr KstBinding::extractMatrix(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) const {
   switch (value.type()) {
     case KJS::ObjectType:
       {
@@ -381,8 +365,7 @@ KstMatrixPtr KstBinding::extractMatrix(KJS::ExecState *exec, const KJS::Value& v
           }
         }
         if (!mp && doThrow) {
-          KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract matrix.");
-          exec->setException(eobj);
+          createGeneralError(exec, i18n("Failed to extract matrix."));
         }
         return mp;
       }
@@ -398,23 +381,21 @@ KstMatrixPtr KstBinding::extractMatrix(KJS::ExecState *exec, const KJS::Value& v
       // fall through and throw
     default:
       if (doThrow) {
-        KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract matrix.");
-        exec->setException(eobj);
+        createGeneralError(exec, i18n("Failed to extract matrix."));
       }
       return 0L;
   }
 }
 
 
-KstViewWindow *KstBinding::extractWindow(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) {
+KstViewWindow *KstBinding::extractWindow(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) const {
   switch (value.type()) {
     case KJS::ObjectType:
       {
         KstBindWindow *imp = dynamic_cast<KstBindWindow*>(value.toObject(exec).imp());
         if (!imp) {
           if (doThrow) {
-            KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract window.");
-            exec->setException(eobj);
+            createGeneralError(exec, i18n("Failed to extract window."));
           }
           return 0L;
         }
@@ -430,23 +411,21 @@ KstViewWindow *KstBinding::extractWindow(KJS::ExecState *exec, const KJS::Value&
       // fall through and throw
     default:
       if (doThrow) {
-        KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract window.");
-        exec->setException(eobj);
+        createGeneralError(exec, i18n("Failed to extract window."));
       }
       return 0L;
   }
 }
 
 
-Kst2DPlotPtr KstBinding::extractPlot(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) {
+Kst2DPlotPtr KstBinding::extractPlot(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) const {
   switch (value.type()) {
     case KJS::ObjectType:
       {
         KstBindPlot *imp = dynamic_cast<KstBindPlot*>(value.toObject(exec).imp());
         if (!imp) {
           if (doThrow) {
-            KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract plot.");
-            exec->setException(eobj);
+            createGeneralError(exec, i18n("Failed to extract plot."));
           }
           return 0L;
         }
@@ -462,15 +441,14 @@ Kst2DPlotPtr KstBinding::extractPlot(KJS::ExecState *exec, const KJS::Value& val
       // fall through and throw
     default:
       if (doThrow) {
-        KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract plot.");
-        exec->setException(eobj);
+        createGeneralError(exec, i18n("Failed to extract plot."));
       }
       return 0L;
   }
 }
 
 
-KstViewObjectPtr KstBinding::extractViewObject(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) {
+KstViewObjectPtr KstBinding::extractViewObject(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) const {
   switch (value.type()) {
     case KJS::ObjectType:
       {
@@ -479,8 +457,7 @@ KstViewObjectPtr KstBinding::extractViewObject(KJS::ExecState *exec, const KJS::
           KstViewWindow *w = extractWindow(exec, value, false);
           if (!w) {
             if (doThrow) {
-              KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract viewObject.");
-              exec->setException(eobj);
+              createGeneralError(exec, i18n("Failed to extract viewObject."));
             }
             return 0L;
           }
@@ -498,15 +475,14 @@ KstViewObjectPtr KstBinding::extractViewObject(KJS::ExecState *exec, const KJS::
       // fall through and throw
     default:
       if (doThrow) {
-        KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract viewObject.");
-        exec->setException(eobj);
+        createGeneralError(exec, i18n("Failed to extract viewObject."));
       }
       return 0L;
   }
 }
 
 
-KstBaseCurveList KstBinding::extractCurveList(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) {
+KstBaseCurveList KstBinding::extractCurveList(KJS::ExecState *exec, const KJS::Value& value, bool doThrow) const {
   KstBaseCurveList rc;
   switch (value.type()) {
     case KJS::ObjectType:
@@ -514,8 +490,7 @@ KstBaseCurveList KstBinding::extractCurveList(KJS::ExecState *exec, const KJS::V
         KstBindCurveCollection *imp = dynamic_cast<KstBindCurveCollection*>(value.toObject(exec).imp());
         if (!imp) {
           if (doThrow) {
-            KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract curve list.");
-            exec->setException(eobj);
+            createGeneralError(exec, i18n("Failed to extract curve list."));
           }
           return rc;
         }
@@ -545,8 +520,7 @@ KstBaseCurveList KstBinding::extractCurveList(KJS::ExecState *exec, const KJS::V
       // fall through and throw
     default:
       if (doThrow) {
-        KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, "Failed to extract curve list.");
-        exec->setException(eobj);
+        createGeneralError(exec, i18n("Failed to extract curve list."));
       }
   }
   return rc;
@@ -562,3 +536,127 @@ int KstBinding::propertyCount() const {
   return 0;
 }
 
+
+void KstBinding::addStackInfoFromContext(const KJS::Context& context, QString& error) const {
+  if (!context.function().isNull()) {
+    if (!context.functionName().isNull()) {
+      int firstLine = context.curStmtFirstLine();
+      int lastLine = context.curStmtLastLine();
+
+      if (firstLine != lastLine) {
+        error += i18n("\n  Function: '%1' Lines: %2-%3").arg(context.functionName().qstring()).arg(firstLine).arg(lastLine);
+      } else {
+        error += i18n("\n  Function: '%1' Line: %2").arg(context.functionName().qstring()).arg(firstLine);
+      }
+
+      addStackInfoFromContext(context.callingContext(), error);
+    }
+  }
+}
+
+
+void KstBinding::addStackInfo(KJS::ExecState *exec, QString& error) const {
+  addStackInfoFromContext(exec->context(), error);
+}
+
+
+KJS::Object KstBinding::createTypeError(KJS::ExecState *exec, int argumentNumber) const {
+  QString error;
+
+  error = i18n("%1: Argument %2 was not of the expected type.").arg(_name).arg(argumentNumber);
+  addStackInfo(exec, error);
+  KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, error.latin1());
+  exec->setException(eobj);
+
+  return KJS::Object();
+}
+
+
+void KstBinding::createPropertyTypeError(KJS::ExecState *exec) const {
+  QString error;
+
+  error = i18n("%1: Argument was not of the expected type.").arg(_name);
+  addStackInfo(exec, error);
+  KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError, error.latin1());
+  exec->setException(eobj);
+
+  return;
+}
+
+
+KJS::Object KstBinding::createSyntaxError(KJS::ExecState *exec) const {
+  QString error;
+
+  error = i18n("%1: Unexpected number of arguments.").arg(_name);
+  addStackInfo(exec, error);
+  KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError, error.latin1());
+  exec->setException(eobj);
+
+  return KJS::Object();
+}
+
+
+KJS::Object KstBinding::createGeneralError(KJS::ExecState *exec, const QString& errorMsg) const {
+  QString error = i18n("%1: %2").arg(_name).arg(errorMsg);
+
+  addStackInfo(exec, error);
+  KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError, error.latin1());
+  exec->setException(eobj);
+
+  return KJS::Object();
+}
+
+
+void KstBinding::createPropertyGeneralError(KJS::ExecState *exec, const QString& errorMsg) const {
+  QString error = i18n("%1: %2").arg(_name).arg(errorMsg);
+
+  addStackInfo(exec, error);
+  KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError, error.latin1());
+  exec->setException(eobj);
+
+  return;
+}
+
+
+KJS::Object KstBinding::createInternalError(KJS::ExecState *exec) const {
+  QString error = i18n("%1: Internal error.").arg(_name);
+
+  addStackInfo(exec, error);
+  KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError, error.latin1());
+  exec->setException(eobj);
+
+  return KJS::Object();
+}
+
+
+void KstBinding::createPropertyInternalError(KJS::ExecState *exec) const {
+  QString error = i18n("%1: Internal error.").arg(_name);
+
+  addStackInfo(exec, error);
+  KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError, error.latin1());
+  exec->setException(eobj);
+
+  return;
+}
+
+
+KJS::Object KstBinding::createRangeError(KJS::ExecState *exec, int argumentNumber) const {
+  QString error = i18n("%1: Argument %2 is out of range.").arg(_name).arg(argumentNumber);
+
+  addStackInfo(exec, error);
+  KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError, error.latin1());
+  exec->setException(eobj);
+
+  return KJS::Object();
+}
+
+
+void KstBinding::createPropertyRangeError(KJS::ExecState *exec) const {
+  QString error = i18n("%1: Value is out of range.").arg(_name);
+
+  addStackInfo(exec, error);
+  KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError, error.latin1());
+  exec->setException(eobj);
+
+  return;
+}
