@@ -336,6 +336,14 @@ bool KstDataSource::supportsHierarchy(const QString& filename, const QString& ty
 }
 
 
+QString KstDataSource::units(const QString& field) {
+  Q_UNUSED(field)
+
+  QString empty;
+
+  return empty;
+}
+
 QStringList KstDataSource::fieldListForSource(const QString& filename, const QString& type, QString *outType, bool *complete) {
   if (filename == "stdin" || filename == "-") {
     return QStringList();
