@@ -193,27 +193,23 @@ class KST_EXPORT KstDataSource : public KstObject {
     virtual bool reset();
 
     virtual const QDict<KstString>& metaData() const;
-
     virtual const QString& metaData(const QString& key) const;
-
     virtual bool hasMetaData() const;
-
     virtual bool hasMetaData(const QString& key) const;
 
     /** Does it support time conversion of sample numbers, in general? */
     virtual bool supportsTimeConversions() const;
-
     virtual int sampleForTime(const KST::ExtDateTime& time, bool *ok = 0L);
-
     virtual int sampleForTime(double milliseconds, bool *ok = 0L);
-
     virtual KST::ExtDateTime timeForSample(int sample, bool *ok = 0L);
-
     // in (ms)
     virtual double relativeTimeForSample(int sample, bool *ok = 0L);
 
     virtual bool supportsHierarchy() const;
 
+    // @since 1.8.0
+    virtual QString units(const QString& field);
+
     /** Allow configuration settings to be set from javaScript.
      *  These methods should be overridden for any datasource that
      *  provides a custom dialog.
@@ -251,8 +247,12 @@ class KST_EXPORT KstDataSource : public KstObject {
 
     KstScalarPtr _numFramesScalar;
 
+    //
     // NOTE: You must bump the version key if you add new member variables
     //       or change or add virtual functions.
+    //       This is done by increasing the value of KST_CURRENT_DATASOURCE_KEY
+    //       in kstobject.h
+    //
 };
 
 
