@@ -21,6 +21,7 @@
 #include <assert.h>
 #include <math.h>
 #include <stdlib.h>
+#include <time.h>
 
 namespace KST {
 
@@ -60,20 +61,52 @@ double extDateTimeToMilliseconds(const ExtDateTime& edt) {
 }
 
 
-ExtDateTime parsePlanckDate(const QString& dateString) {
+double extDateTimeUTCToTime_t(const ExtDateTime& edt) {
+  time_t timeUTC;
+  time_t timeLocal;
+  tm brokenDown;
+  tm tmUTC;
+
+  brokenDown.tm_sec = edt.time().second();
+  brokenDown.tm_min = edt.time().minute();
+  brokenDown.tm_hour = edt.time().hour();
+  brokenDown.tm_mday = edt.date().day();
+  brokenDown.tm_mon = edt.date().month() - 1;
+  brokenDown.tm_year = edt.date().year() - 1900;
+  brokenDown.tm_isdst = 0;
+  timeLocal = mktime( &brokenDown );
+
+  tmUTC = *gmtime( &timeLocal );
+  tmUTC.tm_isdst = 0;
+  timeUTC = mktime( &tmUTC );
+  timeUTC -= 2 * ( timeUTC - timeLocal );
+
+  int secsSince1Jan1970UTC = (int)timeUTC;
+  if ( secsSince1Jan1970UTC < -1 ) {
+    secsSince1Jan1970UTC = -1;
+  }
+
+  return (uint)secsSince1Jan1970UTC;
+}
+
+
+ExtDateTime parsePlanckDate(const QString& dateString, bool applyOffset) {
   QStringList secondSplit = QStringList::split('.', dateString);
   if (secondSplit.isEmpty() || secondSplit.count() > 2) {
     return ExtDateTime();
   }
 
   int seconds = 0;
+  int offset = 0;
   if (secondSplit.count() > 1) {
     seconds = secondSplit[1].toUInt();
   }
 
   QStringList mainSplit = QStringList::split(':', secondSplit[0]);
   ExtDateTime edt = ExtDateTime::currentDateTime();
-  int offset = ExtDateTime::currentDateTime(Qt::UTC).toTime_t() - edt.toTime_t();
+  if (applyOffset) {
+    offset = ExtDateTime::currentDateTime(Qt::UTC).toTime_t() - edt.toTime_t();
+  }
   ExtDate d = edt.date();
   QTime t = edt.time();
   int i = 0;
