@@ -212,6 +212,11 @@ void KstRVector::change(KstDataSourcePtr in_file, const QString &in_field,
 }
 
 
+void KstRVector::resetFile(KstDataSourcePtr in_file) {
+  _file = in_file;
+}
+
+
 void KstRVector::changeFile(KstDataSourcePtr in_file) {
   Q_ASSERT(myLockStatus() == KstRWLock::WRITELOCKED);
 
@@ -342,7 +347,7 @@ void KstRVector::save(QTextStream &ts, const QString& indent, bool saveAbsoluteP
     ts << indent << "  <filename>" << QStyleSheet::escape(_file->fileName()) << "</filename>" << endl;
     _file->unlock();
 
-    ts << indent << "  <field>" << _field << "</field>" << endl;
+    ts << indent << "  <field>" << QStyleSheet::escape(_field) << "</field>" << endl;
     if (saveAbsolutePosition) {
       ts << indent << "  <start>" << _startingFrame << "</start>" << endl;
       ts << indent << "  <num>" << _numberOfFrames << "</num>" << endl;
@@ -628,8 +633,13 @@ KstObject::UpdateType KstRVector::doUpdate(bool force) {
       }
     }
 
-    if (_numberOfFrames > 0) {
-      _numberOfFrames--; /* last frame read was only partially read... */
+    //
+    // if there is more than one sample per frame then
+    //  we read only the first sample in the final frame.
+    // see comment at start of method for further details...
+    //
+    if (_numberOfFrames > 0 && _file->samplesPerFrame(_field) > 1) {
+      _numberOfFrames--;
     }
 
     // read the new data from file
@@ -643,7 +653,6 @@ KstObject::UpdateType KstRVector::doUpdate(bool force) {
       nRead = _file->readField(_v+_numberOfFrames*_samplesPerFrame, _field, newStartingFrame + _numberOfFrames, newNumberOfFrames - _numberOfFrames - 1);
       nRead += _file->readField(_v+(newNumberOfFrames-1)*_samplesPerFrame, _field, newStartingFrame + newNumberOfFrames - 1, -1);
     } else {
-      //kstdDebug() << "Reading into _v=" << (void*)_v << " which has size " << _size << " and starting at offset " << NF*_samplesPerFrame << " for s=" << newStartingFrame + NF << " and n=" << newNumberOfFrames - NF << endl;
       assert(newStartingFrame + _numberOfFrames >= 0);
       if (newNumberOfFrames - _numberOfFrames > 0 || newNumberOfFrames - _numberOfFrames == -1) {
         nRead = _file->readField(_v+_numberOfFrames*_samplesPerFrame, _field, newStartingFrame + _numberOfFrames, newNumberOfFrames - _numberOfFrames);
@@ -656,6 +665,7 @@ KstObject::UpdateType KstRVector::doUpdate(bool force) {
   _startingFrame = newStartingFrame;
   _numSamples += nRead;
 
+  //
   // if for some reason (eg, realtime reading an nfs mounted
   // dirfile) not all of the data was read, the data will never
   // be read; the samples will be filled in with the last data
@@ -663,9 +673,9 @@ KstObject::UpdateType KstRVector::doUpdate(bool force) {
   // This is bad - I think it will be worthwhile
   // to add blocking w/ timeout to KstFile.
   // As a first fix, mount all nsf mounted dirfiles with "-o noac"
+  //
   _dirty = false;
   if (_numSamples != _size && !(_numSamples == 0 && _size == 1)) {
-    //kstdDebug() << "SET DIRTY since _numSamples = " << _numSamples << " but _size = " << _size << endl;
     _dirty = true;
     for (i = _numSamples; i < _size; i++) {
       _v[i] = _v[0];
@@ -675,6 +685,7 @@ KstObject::UpdateType KstRVector::doUpdate(bool force) {
   if (_numNew > _size) {
     _numNew = _size;
   }
+
   if (_numShifted > _size) {
     _numShifted = _size;
   }
