@@ -645,7 +645,7 @@ QString KstVector::fileLabel() const {
 }
 
 
-double *const KstVector::value() const {
+double* KstVector::value() const {
   return _v;
 }
 
