@@ -470,7 +470,7 @@ void KstApp::initActions() {
 
 
   /************/
-  NewPlotAction = new KAction(i18n("New Plot..."), "kst_newplot", 0,
+  NewPlotAction = new KAction(i18n("New Plot"), "kst_newplot", 0,
                                  this, SLOT(newPlot()),
                                  actionCollection(), "newplot_action");
   NewPlotAction->setWhatsThis(i18n("Create a new plot in the\n"
@@ -1726,7 +1726,7 @@ void KstApp::updateStatusBarText() {
       widthAvailable -= _dataNotifier->geometry().width();
       widthAvailable -= spacing;
     }
-    
+
     widthUsed  = widthData;
     widthUsed += widthReady;
 #ifdef HAVE_LINUX
@@ -2296,7 +2296,6 @@ void KstApp::showDataWizardWithFile(const QString &input) {
 
 
 void KstApp::registerDocChange() {
-  kstdDebug() << "register doc changed" << endl;
   forceUpdate();
   updateVisibleDialogs();
   doc->setModified();
@@ -2305,26 +2304,154 @@ void KstApp::registerDocChange() {
 
 void KstApp::reload() {
   QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+
+  QMap<KstDataSourcePtr, KstDataSourcePtr> dataSourcesReset;
+  QMap<KstDataSourcePtr, KstDataSourcePtr> dataSourcesReloaded;
+
   KST::vectorList.lock().readLock();
   for (KstVectorList::ConstIterator i = KST::vectorList.begin(); i != KST::vectorList.end(); ++i) {
     KstRVectorPtr r = kst_cast<KstRVector>(*i);
     if (r) {
+      KstDataSourcePtr dataSrc;
+
       r->writeLock();
-      r->reload();
+
+      dataSrc = r->dataSource();
+      if (dataSrc) {
+        if (dataSourcesReset.contains(dataSrc)) {
+          //
+          // if we've already reset the datasource held by this vector then
+          //  we only need to reset the vector itself...
+          //
+          r->reset();
+        } else {
+          dataSrc->writeLock();
+
+          if (dataSrc->reset()) {
+            //
+            // if we were successful in resetting the datasource held by this vector then
+            //  we remember it and reset the vector itself...
+            //
+            dataSourcesReset.insert(dataSrc, dataSrc);
+            r->reset();
+          } else {
+            //
+            // we have to try and reload the datasource...
+            //
+            QMap<KstDataSourcePtr, KstDataSourcePtr>::Iterator itsrc = dataSourcesReloaded.find(dataSrc);
+
+            if (itsrc == dataSourcesReloaded.end()) {
+              //
+              // if we haven't yet reloaded this datasource then do so now...
+              //
+              KstDataSourcePtr newsrc = KstDataSource::loadSource(dataSrc->fileName(), dataSrc->fileType());
+              if (newsrc) {
+                newsrc->writeLock();
+
+                KST::dataSourceList.lock().writeLock();
+                KST::dataSourceList.remove(dataSrc);
+                KST::dataSourceList.append(newsrc);
+                KST::dataSourceList.lock().unlock();
+
+                dataSourcesReloaded.insert(dataSrc, newsrc);
+
+                r->resetFile(newsrc);
+                r->reset();
+
+                newsrc->unlock();
+              }
+            } else {
+              //
+              // we have already reloaded this datasource, so just set it...
+              //
+              (*itsrc)->writeLock();
+              r->resetFile(*itsrc);
+              r->reset();
+              (*itsrc)->unlock();
+            }
+          }
+
+          dataSrc->unlock();
+        }
+      }
+
       r->unlock();
     }
   }
   KST::vectorList.lock().unlock();
+
   KST::matrixList.lock().readLock();
   for (KstMatrixList::ConstIterator i = KST::matrixList.begin(); i != KST::matrixList.end(); ++i) {
     KstRMatrixPtr r = kst_cast<KstRMatrix>(*i);
     if (r) {
+      KstDataSourcePtr dataSrc;
+
       r->writeLock();
-      r->reload();
+
+      dataSrc = r->dataSource();
+      if (dataSrc) {
+        if (dataSourcesReset.contains(dataSrc)) {
+          //
+          // if we've already reset the datasource held by this matrix then
+          //  we only need to reset the matrix itself...
+          //
+          r->reset();
+        } else {
+          dataSrc->writeLock();
+
+          if (dataSrc->reset()) {
+            //
+            // if we were successful in resetting the datasource held by this matrix then
+            //  we remember it and reset the matrix itself...
+            //
+            dataSourcesReset.insert(dataSrc, dataSrc);
+            r->reset();
+          } else {
+            //
+            // we have to try and reload the datasource...
+            //
+            QMap<KstDataSourcePtr, KstDataSourcePtr>::Iterator itsrc = dataSourcesReloaded.find(dataSrc);
+
+            if (itsrc == dataSourcesReloaded.end()) {
+              //
+              // if we haven't yet reloaded this datasource then do so now...
+              //
+              KstDataSourcePtr newsrc = KstDataSource::loadSource(dataSrc->fileName(), dataSrc->fileType());
+              if (newsrc) {
+                newsrc->writeLock();
+
+                KST::dataSourceList.lock().writeLock();
+                KST::dataSourceList.remove(dataSrc);
+                KST::dataSourceList.append(newsrc);
+                KST::dataSourceList.lock().unlock();
+
+                dataSourcesReloaded.insert(dataSrc, newsrc);
+
+                r->resetFile(newsrc);
+                r->reset();
+
+                newsrc->unlock();
+              }
+            } else {
+              //
+              // we have already reloaded this datasource, so just set it...
+              //
+              (*itsrc)->writeLock();
+              r->resetFile(*itsrc);
+              r->reset();
+              (*itsrc)->unlock();
+            }
+          }
+
+          dataSrc->unlock();
+        }
+      }
+
       r->unlock();
     }
   }
   KST::matrixList.lock().unlock();
+
   QApplication::restoreOverrideCursor();
 }
 
@@ -2692,6 +2819,21 @@ void KstApp::moveTabRight(KstViewWindow *tab) {
 }
 
 
+void KstApp::saveTabs(QTextStream& ts) {
+  KTabWidget *tw = tabWidget();
+  if (tw) {
+    for (int tab=0; tab<tw->count(); ++tab) {
+      KstViewWindow *v = dynamic_cast<KstViewWindow*>(tw->page(tab));
+      if (v) {
+        ts << "  <window>" << endl;
+        v->save(ts, "    ");
+        ts << "  </window>" << endl;
+      }
+    }
+  }
+}
+
+
 void KstApp::emitTimezoneChanged(const QString& tz, int utcOffset) {
   emit timezoneChanged(tz, utcOffset);
 }
