@@ -472,25 +472,10 @@ bool KstDoc::openDocument(const KURL& url, const QString& o_file,
         KstWriteLocker dowl(&KST::dataObjectList.lock());
         KST::dataObjectList.append(p);
       } else if (e.tagName() == "window") {
-        KstViewWindow *p = dynamic_cast<KstViewWindow*>(app->activeWindow());
-        KstViewWindow *toDelete = 0L;
+        KstViewWindow *p = new KstViewWindow(e);
 
-        if (!p) {
-          KMdiIterator<KMdiChildView*> *it = app->createIterator();
-          p = dynamic_cast<KstViewWindow*>(it->currentItem());
-          app->deleteIterator(it);
-        }
-
-        if (p && p->view()->children().count() == 0) {
-          toDelete = p;
-        }
-
-        p = new KstViewWindow(e);
         app->addWindow(p, KMdi::StandardAdd | KMdi::UseKMdiSizeHint);
         p->activate();
-        if (toDelete) {
-          app->closeWindow(toDelete);
-        }
       } else {
         KstDebug::self()->log(i18n("Unsupported element '%1' in file %2.").arg(e.tagName()).arg(url.prettyURL()), KstDebug::Warning);
       }
@@ -640,6 +625,7 @@ bool KstDoc::openDocument(const KURL& url, const QString& o_file,
 
 void KstDoc::saveDocument(QTextStream& ts, bool saveAbsoluteVectorPositions) {
   KstApp *app = KstApp::inst();
+
   ts << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << endl;
   ts << "<kstdoc version=\"1.3\">" << endl;
   // save window geometry for this kst file
@@ -730,8 +716,8 @@ void KstDoc::saveDocument(QTextStream& ts, bool saveAbsoluteVectorPositions) {
   // save matrices
   for (KstMatrixList::Iterator it = KST::matrixList.begin(); it != KST::matrixList.end(); ++it) {
     if ((*it)->saveable()) {
-      (*it)->save(ts, "  ");  
-    }  
+      (*it)->save(ts, "  ");
+    }
   }
 
   // save data objects
@@ -760,20 +746,7 @@ void KstDoc::saveDocument(QTextStream& ts, bool saveAbsoluteVectorPositions) {
   }
   app->deleteIterator(it);
 
-  // save windows
-  it = app->createIterator();
-  if (it) {
-    while (it->currentItem()) {
-      KstViewWindow *v = dynamic_cast<KstViewWindow*>(it->currentItem());
-      if (v) {
-        ts << "  <window>" << endl;
-        v->save(ts, "    ");
-        ts << "  </window>" << endl;
-      }
-      it->next();
-    }
-    app->deleteIterator(it);
-  }
+  app->saveTabs(ts);
 
   ts << "</kstdoc>" << endl;
 }
@@ -1296,111 +1269,104 @@ void KstDoc::createScalars() const {
 
 // All code after this point is code copied from KDE libraries
 static int write_all(int fd, const char *buf, size_t len) {
-   while (len > 0)
-   {
-      int written = write(fd, buf, len);
-      if (written < 0)
-      {
-          if (errno == EINTR)
-             continue;
-          return -1;
+  while (len > 0) {
+    int written = write(fd, buf, len);
+    if (written < 0) {
+      if (errno == EINTR) {
+        continue;
       }
-      buf += written;
-      len -= written;
-   }
-   return 0;
+      return -1;
+    }
+    buf += written;
+    len -= written;
+  }
+  return 0;
 }
 
 static bool backupFile(const QString& qFilename, const QString& backupDir,
                        const QString& backupExtension) {
-   QCString cFilename = QFile::encodeName(qFilename);
-   const char *filename = cFilename.data();
+  QCString cFilename = QFile::encodeName(qFilename);
+  const char *filename = cFilename.data();
 
-   int fd = open(filename, O_RDONLY);
-   if (fd < 0) {
-      return false;
-   }
+  int fd = open(filename, O_RDONLY);
+  if (fd < 0) {
+    return false;
+  }
 
-   struct stat buff;
-   if ( fstat( fd, &buff) < 0 )
-   {
-      ::close( fd );
-      return false;
-   }
+  struct stat buff;
+  if ( fstat( fd, &buff) < 0 ) {
+    ::close( fd );
+    return false;
+  }
 
-   QCString cBackup;
-   if ( backupDir.isEmpty() ) {
-       cBackup = cFilename;
-   }
-   else
-   {
-       QCString nameOnly;
-       int slash = cFilename.findRev('/');
-       if (slash < 0)
-         nameOnly = cFilename;
-       else
-         nameOnly = cFilename.mid(slash + 1);
-       cBackup = QFile::encodeName(backupDir);
-       if ( backupDir[backupDir.length()-1] != '/' ) {
-           cBackup += '/';
-       }
-       cBackup += nameOnly;
-   }
-   cBackup += QFile::encodeName(backupExtension);
-   const char *backup = cBackup.data();
-   int permissions = buff.st_mode & 07777;
+  QCString cBackup;
+  if ( backupDir.isEmpty() ) {
+    cBackup = cFilename;
+  } else {
+    QCString nameOnly;
+    int slash = cFilename.findRev('/');
 
-   if ( stat( backup, &buff) == 0)
-   {
-      if ( unlink( backup ) != 0 )
-      {
-         ::close(fd);
-         return false;
-      }
-   }
+    if (slash < 0) {
+      nameOnly = cFilename;
+    } else {
+      nameOnly = cFilename.mid(slash + 1);
+    }
+    cBackup = QFile::encodeName(backupDir);
+    if ( backupDir[backupDir.length()-1] != '/' ) {
+      cBackup += '/';
+    }
+    cBackup += nameOnly;
+  }
+  cBackup += QFile::encodeName(backupExtension);
+  const char *backup = cBackup.data();
+  int permissions = buff.st_mode & 07777;
 
-   mode_t old_umask = umask(0);
-   int fd2 = open( backup, O_WRONLY | O_CREAT | O_EXCL, permissions | S_IWUSR);
-   umask(old_umask);
-
-   if ( fd2 < 0 )
-   {
+  if ( stat( backup, &buff) == 0) {
+    if ( unlink( backup ) != 0 ) {
       ::close(fd);
       return false;
-   }
-
-    char buffer[ 32*1024 ];
-
-    while( 1 )
-    {
-       int n = ::read( fd, buffer, 32*1024 );
-       if (n == -1)
-       {
-          if (errno == EINTR) {
-              continue;
-          }
-          ::close(fd);
-          ::close(fd2);
-          return false;
-       }
-       if (n == 0) {
-          break; // Finished
-       }
-
-       if (write_all( fd2, buffer, n))
-       {
-          ::close(fd);
-          ::close(fd2);
-          return false;
-       }
     }
+  }
 
-    ::close( fd );
+  mode_t old_umask = umask(0);
+  int fd2 = open( backup, O_WRONLY | O_CREAT | O_EXCL, permissions | S_IWUSR);
+  umask(old_umask);
 
-    if (::close(fd2)) {
+  if ( fd2 < 0 ) {
+    ::close(fd);
+    return false;
+  }
+
+  char buffer[ 32*1024 ];
+
+  while( 1 ) {
+    int n = ::read( fd, buffer, 32*1024 );
+    if (n == -1) {
+      if (errno == EINTR) {
+        continue;
+      }
+      ::close(fd);
+      ::close(fd2);
       return false;
     }
-    return true;
+    if (n == 0) {
+      break; // Finished
+    }
+
+    if (write_all( fd2, buffer, n)) {
+      ::close(fd);
+      ::close(fd2);
+      return false;
+    }
+  }
+
+  ::close( fd );
+
+  if (::close(fd2)) {
+    return false;
+  }
+
+  return true;
 }
 
 #include "kstdoc.moc"
