@@ -90,7 +90,11 @@ void KstEditViewObjectDialogI::showEditViewObjectDialog(KstViewObjectPtr viewObj
   _top = top;
   updateWidgets();
   if (_viewObject) {
-    setCaption(_viewObject->editTitle());
+    if (_isNew) {
+      setCaption(_viewObject->newTitle());
+    } else {
+      setCaption(_viewObject->editTitle());
+    }
     if (_viewObject && !_viewObject->supportsDefaults()) {
       _buttonGroupDefaults->hide();
       _pushButtonSetDefaults->hide();
@@ -219,149 +223,125 @@ void KstEditViewObjectDialogI::clearWidgets() {
 }
 
 
-void KstEditViewObjectDialogI::updateWidgets() {
-  clearWidgets();
+void KstEditViewObjectDialogI::updateDefaultWidgets() {
+  int numProperties = _viewObject->metaObject()->numProperties(true);
 
-  // get the qt properties of the viewobject
-  if (_viewObject) {
-    _customWidget = _viewObject->configWidget(_propertiesFrame);
-    if (_customWidget) {
-      _grid = new QGridLayout(_propertiesFrame, 1, 1);
-      _customWidget->show();
-      _grid->addWidget(_customWidget, 0, 0);
-      _viewObject->fillConfigWidget(_customWidget, _isNew);
-      if (!_isNew) {
-        _viewObject->connectConfigWidget(this, _customWidget);
+  // create a new grid
+  _grid = new QGridLayout(_propertiesFrame, numProperties, 2, 0, 8);
+  _grid->setColStretch(0, 0);
+  _grid->setColStretch(1, 1);
+
+  // get the property names and types
+  for (int i = 0; i < numProperties; i++) {
+    const QMetaProperty* property = _viewObject->metaObject()->property(i, true);
+    QString propertyType(property->type());
+    QString propertyName(property->name());
+
+    // for this property, get the meta-data map
+    QMap<QString, QVariant> metaData = _viewObject->widgetHints(propertyName);
+
+    if (!metaData.empty()) {
+      QString friendlyName = metaData["_kst_label"].toString();
+      QString widgetType = metaData["_kst_widgetType"].toString();
+      metaData.erase("_kst_label");
+      metaData.erase("_kst_widgetType");
+
+      // use friendly name for label
+      QLabel* propertyLabel = new QLabel(_propertiesFrame, "label-"+i);
+      propertyLabel->setText(friendlyName);
+      _grid->addWidget(propertyLabel, i, 0);
+      propertyLabel->show();
+      _widgets.append(propertyLabel);
+
+      // display different types of widgets depending on what dialogData specifies
+      QWidget* propertyWidget = 0L;
+
+      if (widgetType == "QSpinBox") {
+        propertyWidget = new QSpinBox(_propertiesFrame, (propertyName+","+"value").latin1()); 
+        propertyWidget->setProperty("value", _viewObject->property(property->name()));
+        if (!_isNew) {
+          connect(propertyWidget, SIGNAL(valueChanged(const QString&)), this, SLOT(modified()));
+          connect(propertyWidget->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), this, SLOT(modified()));
+        }
+      } else if (widgetType == "KColorButton") {
+        propertyWidget = new KColorButton(_propertiesFrame, (propertyName+","+"color").latin1());
+        propertyWidget->setProperty("color", _viewObject->property(property->name()));
+        if (!_isNew) {
+          connect(propertyWidget, SIGNAL(changed(const QColor&)), this, SLOT(modified()));
+        }
+      } else if (widgetType == "QLineEdit") {
+        propertyWidget = new QLineEdit(_propertiesFrame, (propertyName+","+"text").latin1());
+        propertyWidget->setProperty("text", _viewObject->property(property->name()));
+        if (!_isNew) {
+          connect(propertyWidget, SIGNAL(textChanged(const QString&)), this, SLOT(modified()));
+        }
+      } else if (widgetType == "KURLRequester") {
+        propertyWidget = new KURLRequester(_propertiesFrame, (propertyName+","+"url").latin1());
+        propertyWidget->setProperty("url", _viewObject->property(property->name()));
+        if (!_isNew) {
+          connect(propertyWidget, SIGNAL(textChanged(const QString&)), this, SLOT(modified()));
+          connect(propertyWidget, SIGNAL(urlSelected(const QString&)), this, SLOT(modified()));
+        }
+      } else if (widgetType == "PenStyleWidget") {
+        // insert a combobox with QT pen styles
+        QComboBox* combo = new QComboBox(_propertiesFrame, (propertyName+","+"currentItem").latin1());
+        fillPenStyleWidget(combo);
+        propertyWidget = combo;
+        propertyWidget->setProperty("currentItem", _viewObject->property(property->name()));
+        if (!_isNew) {
+          connect(propertyWidget, SIGNAL(activated(int)), this, SLOT(modified()));
+        }
+      } else if (widgetType == "QCheckBox") {
+        propertyWidget = new QCheckBox(_propertiesFrame, (propertyName+","+"checked").latin1());
+        propertyWidget->setProperty("checked", _viewObject->property(property->name()));
+        if (!_isNew) {
+          connect(propertyWidget, SIGNAL(pressed()), this, SLOT(modified()));
+        }
+      } else if (widgetType == "KDoubleSpinBox") {
+        KDoubleSpinBox* input = new KDoubleSpinBox(_propertiesFrame, (propertyName+","+"value").latin1());
+        input->setPrecision(metaData["precision"].toInt());
+        input->setMinValue(metaData["minValue"].toDouble());
+        input->setMaxValue(metaData["maxValue"].toDouble());
+        input->setLineStep(metaData["lineStep"].toDouble());
+        metaData.erase("minValue");
+        metaData.erase("maxValue");
+        metaData.erase("lineStep");
+        metaData.erase("precision");
+        propertyWidget = input; 
+        propertyWidget->setProperty("value", _viewObject->property(property->name()));
+        // need the following line because of a KDE bug causing valueChanged(double) never to be emitted 
+        if (!_isNew) {
+          connect(propertyWidget, SIGNAL(valueChanged(int)), this, SLOT(modified()));
+          connect(propertyWidget, SIGNAL(valueChanged(double)), this, SLOT(modified()));
+          connect(propertyWidget->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), this, SLOT(modified()));
+        }
+      } else if (widgetType == "KFontCombo") {
+        propertyWidget = new KFontCombo(_propertiesFrame, (propertyName+","+"currentText").latin1());
+        propertyWidget->setProperty("currentText", _viewObject->property(property->name()));  
+        if (!_isNew) {
+          connect(propertyWidget, SIGNAL(activated(int)), this, SLOT(modified()));
+        }
+      } else if (widgetType == "HJustifyCombo") {
+        // insert a combo box filled with horizontal justifications
+        QComboBox* combo = new QComboBox(_propertiesFrame, (propertyName+","+"currentItem").latin1());
+        fillHJustifyWidget(combo);
+        propertyWidget = combo;
+        propertyWidget->setProperty("currentItem", _viewObject->property(property->name()));
+        if (!_isNew) {
+          connect(propertyWidget, SIGNAL(activated(int)), this, SLOT(modified()));
+        }
+      } else if (widgetType == "VJustifyCombo") {
+        // insert a combo box filled with vertical justifications
+        QComboBox* combo = new QComboBox(_propertiesFrame, (propertyName+","+"currentItem").latin1());
+        fillVJustifyWidget(combo);
+        propertyWidget = combo;
+        propertyWidget->setProperty("currentItem", _viewObject->property(property->name()));
+        if (!_isNew) {
+          connect(propertyWidget, SIGNAL(activated(int)), this, SLOT(modified()));
+        }
       }
 
-      return;
-    }
-
-    //---------------------------------------------------------------
-    // NOTE: due to Early return, nothing after this line is executed
-    // if the view object provides a custom widget.
-    int numProperties = _viewObject->metaObject()->numProperties(true);
-
-    // create a new grid
-    _grid = new QGridLayout(_propertiesFrame, numProperties, 2, 0, 8);
-    _grid->setColStretch(0, 0);
-    _grid->setColStretch(1, 1);
-
-    // get the property names and types
-    for (int i = 0; i < numProperties; i++) {
-      const QMetaProperty* property = _viewObject->metaObject()->property(i, true);
-      QString propertyType(property->type());
-      QString propertyName(property->name());
-
-      // for this property, get the meta-data map
-      QMap<QString, QVariant> metaData = _viewObject->widgetHints(propertyName);
-
-      if (!metaData.empty()) {
-        QString friendlyName = metaData["_kst_label"].toString();
-        QString widgetType = metaData["_kst_widgetType"].toString();
-        metaData.erase("_kst_label");
-        metaData.erase("_kst_widgetType");
-
-        // use friendly name for label
-        QLabel* propertyLabel = new QLabel(_propertiesFrame, "label-"+i);
-        propertyLabel->setText(friendlyName);
-        _grid->addWidget(propertyLabel, i, 0);
-        propertyLabel->show();
-        _widgets.append(propertyLabel);
-
-        // display different types of widgets depending on what dialogData specifies
-        QWidget* propertyWidget = 0L;
-        if (widgetType == "QSpinBox") {
-          // insert a spinbox
-          propertyWidget = new QSpinBox(_propertiesFrame, (propertyName+","+"value").latin1()); 
-          propertyWidget->setProperty("value", _viewObject->property(property->name()));
-          if (!_isNew) {
-            connect(propertyWidget, SIGNAL(valueChanged(const QString&)), this, SLOT(modified()));
-            connect(propertyWidget->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), this, SLOT(modified()));
-          }
-        } else if (widgetType == "KColorButton") {
-          // insert a colorbutton
-          propertyWidget = new KColorButton(_propertiesFrame, (propertyName+","+"color").latin1());
-          propertyWidget->setProperty("color", _viewObject->property(property->name()));
-          if (!_isNew) {
-            connect(propertyWidget, SIGNAL(changed(const QColor&)), this, SLOT(modified()));
-          }
-        } else if (widgetType == "QLineEdit") {
-          // insert a text field
-          propertyWidget = new QLineEdit(_propertiesFrame, (propertyName+","+"text").latin1());
-          propertyWidget->setProperty("text", _viewObject->property(property->name()));
-          if (!_isNew) {
-            connect(propertyWidget, SIGNAL(textChanged(const QString&)), this, SLOT(modified()));
-          }
-        } else if (widgetType == "KURLRequester") {
-          // insert a url requester
-          propertyWidget = new KURLRequester(_propertiesFrame, (propertyName+","+"url").latin1());
-          propertyWidget->setProperty("url", _viewObject->property(property->name()));
-          if (!_isNew) {
-            connect(propertyWidget, SIGNAL(textChanged(const QString&)), this, SLOT(modified()));
-            connect(propertyWidget, SIGNAL(urlSelected(const QString&)), this, SLOT(modified()));
-          }
-        } else if (widgetType == "PenStyleWidget") {
-          // insert a combobox with QT pen styles
-          QComboBox* combo = new QComboBox(_propertiesFrame, (propertyName+","+"currentItem").latin1());
-          fillPenStyleWidget(combo);
-          propertyWidget = combo;
-          propertyWidget->setProperty("currentItem", _viewObject->property(property->name()));
-          if (!_isNew) {
-            connect(propertyWidget, SIGNAL(activated(int)), this, SLOT(modified()));
-          }
-        } else if (widgetType == "QCheckBox") {
-          // insert a checkbox
-          propertyWidget = new QCheckBox(_propertiesFrame, (propertyName+","+"checked").latin1());
-          propertyWidget->setProperty("checked", _viewObject->property(property->name()));
-          if (!_isNew) {
-            connect(propertyWidget, SIGNAL(pressed()), this, SLOT(modified()));
-          }
-        } else if (widgetType == "KDoubleSpinBox") {
-          // insert a double num spinbox
-          KDoubleSpinBox* input = new KDoubleSpinBox(_propertiesFrame, (propertyName+","+"value").latin1());
-          // need this so that setValue later works
-          input->setMinValue(metaData["minValue"].toDouble());
-          input->setMaxValue(metaData["maxValue"].toDouble());
-          input->setLineStep(metaData["lineStep"].toDouble());
-          metaData.erase("minValue");
-          metaData.erase("maxValue");
-          metaData.erase("lineStep");
-          propertyWidget = input; 
-          propertyWidget->setProperty("value", _viewObject->property(property->name()));
-          // need the following line because of a KDE bug causing valueChanged(double) never to be emitted 
-          if (!_isNew) {
-            connect(propertyWidget, SIGNAL(valueChanged(int)), this, SLOT(modified()));
-            connect(propertyWidget, SIGNAL(valueChanged(double)), this, SLOT(modified()));
-            connect(propertyWidget->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), this, SLOT(modified()));
-          }
-        } else if (widgetType == "KFontCombo") {
-          // insert a font combo box
-          propertyWidget = new KFontCombo(_propertiesFrame, (propertyName+","+"currentText").latin1());
-          propertyWidget->setProperty("currentText", _viewObject->property(property->name()));  
-          if (!_isNew) {
-            connect(propertyWidget, SIGNAL(activated(int)), this, SLOT(modified()));
-          }
-        } else if (widgetType == "HJustifyCombo") {
-          // insert a combo box filled with horizontal justifications
-          QComboBox* combo = new QComboBox(_propertiesFrame, (propertyName+","+"currentItem").latin1());
-          fillHJustifyWidget(combo);
-          propertyWidget = combo;
-          propertyWidget->setProperty("currentItem", _viewObject->property(property->name()));
-          if (!_isNew) {
-            connect(propertyWidget, SIGNAL(activated(int)), this, SLOT(modified()));
-          }
-        } else if (widgetType == "VJustifyCombo") {
-          // insert a combo box filled with vertical justifications
-          QComboBox* combo = new QComboBox(_propertiesFrame, (propertyName+","+"currentItem").latin1());
-          fillVJustifyWidget(combo);
-          propertyWidget = combo;
-          propertyWidget->setProperty("currentItem", _viewObject->property(property->name()));
-          if (!_isNew) {
-            connect(propertyWidget, SIGNAL(activated(int)), this, SLOT(modified()));
-          }
-        }
-
+      if (propertyWidget != 0L) {
         propertyWidget->show();
 
         // also set any additional properties specified by metaData
@@ -377,6 +357,26 @@ void KstEditViewObjectDialogI::updateWidgets() {
 }
 
 
+void KstEditViewObjectDialogI::updateWidgets() {
+  clearWidgets();
+
+  if (_viewObject) {
+    _customWidget = _viewObject->configWidget(_propertiesFrame);
+    if (_customWidget) {
+      _grid = new QGridLayout(_propertiesFrame, 1, 1);
+      _customWidget->show();
+      _grid->addWidget(_customWidget, 0, 0);
+      _viewObject->fillConfigWidget(_customWidget, _isNew);
+      if (!_isNew) {
+        _viewObject->connectConfigWidget(this, _customWidget);
+      }
+    } else {
+      updateDefaultWidgets();
+    }
+  }
+}
+
+
 void KstEditViewObjectDialogI::fillPenStyleWidget(QComboBox* widget) {
   QRect rect = widget->style().querySubControlMetrics(QStyle::CC_ComboBox, 
                                                       widget, 
@@ -386,7 +386,6 @@ void KstEditViewObjectDialogI::fillPenStyleWidget(QComboBox* widget) {
   rect.setTop(rect.top() + 2);
   rect.setBottom(rect.bottom() - 2);
 
-  // fill the combo with pen styles
   QPixmap ppix(rect.width(), rect.height());
   QPainter pp(&ppix);
   QPen pen(Qt::black, 0);
