@@ -388,11 +388,13 @@ void KstVectorDialogI::fillFieldsForNew() {
 
 bool KstVectorDialogI::newObject() {
   KstDataSourcePtr file;
-  QString tag_name = _tagName->text();
+  QString tagName = _tagName->text();
 
   if (_w->_readFromSource->isChecked()) {
-    tag_name.replace(defaultTag, _w->Field->currentText());
-    tag_name = KST::suggestVectorName(tag_name);
+    tagName.replace(defaultTag, _w->Field->currentText());
+    tagName = KST::suggestVectorName(tagName);
+    tagName.remove('[');
+    tagName.remove(']');
 
     // if there is not an active DataSource, create one
     {
@@ -454,10 +456,12 @@ bool KstVectorDialogI::newObject() {
     }
     file->unlock();
 
+    //
     // create the vector
+    //
     KstRVectorPtr vector = new KstRVector(
         file, _w->Field->currentText(),
-        KstObjectTag(tag_name, file->tag(), false),
+        KstObjectTag(tagName, file->tag(), false),
         _w->_kstDataRange->CountFromEnd->isChecked() ? -1 : f0,
         _w->_kstDataRange->ReadToEnd->isChecked() ? -1 : n,
         _w->_kstDataRange->Skip->value(),
@@ -471,12 +475,16 @@ bool KstVectorDialogI::newObject() {
     double x0 = _w->_xMin->text().toDouble();
     double x1 = _w->_xMax->text().toDouble();
     int n = _w->_N->value();
-    QString tagname = _tagName->text();
-    if (tagname == defaultTag) {
-      tagname = KST::suggestVectorName(QString("(%1..%2)").arg(x0).arg(x1));
+    QString tagName = _tagName->text();
+
+    if (tagName == defaultTag) {
+      tagName = KST::suggestVectorName(QString("(%1..%2)").arg(x0).arg(x1));
+    } else {
+      tagName.remove('[');
+      tagName.remove(']');
     }
 
-    KstSVectorPtr svector = new KstSVector(x0, x1, n, KstObjectTag(tagname, KstObjectTag::globalTagContext));
+    KstSVectorPtr svector = new KstSVector(x0, x1, n, KstObjectTag(tagName, KstObjectTag::globalTagContext));
     emit vectorCreated(KstVectorPtr(svector));
     svector = 0L;
     emit modified();
