@@ -25,12 +25,12 @@
 #include "kstgfxlegendmousehandler.h"
 #include "kstdataobjectcollection.h"
 #include "kstlegenddefaults.h"
+#include "kstviewlegendwidget_i.h"
 #include "kst.h"
 #include "kstsettings.h"
 #include "ksttimers.h"
 #include "kstviewobjectfactory.h"
 #include "labelrenderer.h"
-#include "viewlegendwidget.h"
 #include "plotlistbox.h"
 #include "kstviewwindow.h"
 
@@ -60,6 +60,7 @@
 KstViewLegend::KstViewLegend()
 : KstBorderedViewObject("Legend") {
   _editTitle = i18n("Edit Legend");
+  _newTitle = i18n("New Legend");
   _fontName = KST::legendDefaults.font();
   _vertical = KST::legendDefaults.vertical();
   _legendMargin = KST::legendDefaults.margin();
@@ -90,6 +91,7 @@ KstViewLegend::KstViewLegend()
 KstViewLegend::KstViewLegend(const QDomElement& e)
 : KstBorderedViewObject(e) {
   _editTitle = i18n("Edit Legend");
+  _newTitle = i18n("New Legend");
   _fontName = KST::legendDefaults.font();
   _vertical = KST::legendDefaults.vertical();
   _legendMargin = KST::legendDefaults.margin();
@@ -152,6 +154,7 @@ KstViewLegend::KstViewLegend(const QDomElement& e)
 KstViewLegend::KstViewLegend(const KstViewLegend& legend)
 : KstBorderedViewObject(legend) {
   _editTitle = i18n("Edit Legend");
+  _newTitle = i18n("New Legend");
   _type = "Legend";
   _layoutActions &= ~(MoveTo | Copy | CopyTo);
   _standardActions |= Delete | Edit;
@@ -228,7 +231,7 @@ void KstViewLegend::save(QTextStream &ts, const QString& indent) {
   reparseTitle();
   ts << indent << "<" << type() << ">" << endl;
   KstBorderedViewObject::save(ts, indent + "  ");
-  
+
   for (KstBaseCurveList::ConstIterator j = _curves.begin(); j != _curves.end(); ++j) {
     (*j)->readLock();
     ts << indent+"  " << "<curvetag>" << QStyleSheet::escape((*j)->tagName()) << "</curvetag>" << endl;
@@ -268,6 +271,7 @@ void KstViewLegend::drawToPainter(KstPainter& p) {
       rc.x = 0;
       rc.y = _ascent;
       rc.xStart = rc.x;
+      rc.pen = foregroundColor();
       if (_parsedTitle->chunk) {
         _parsedTitle->chunk->attributes.color = foregroundColor();
       }
@@ -433,6 +437,7 @@ QRegion KstViewLegend::clipRegion() {
   if (_clipMask.isNull()) {
     if (_transparent) {
       const QRect cr(contentsRect());
+
       // slow but preserves antialiasing...
       QBitmap bm = _backBuffer.buffer().createHeuristicMask(false);
 
@@ -528,21 +533,23 @@ QSize KstViewLegend::sizeForText(const QRect& w) {
   }
 
   QSize sz(width, height);
-  
+
   sz += QSize(2 * _legendMargin * _ascent / 10, 2 * _legendMargin * _ascent / 10);
 
   if (_parent) {
     QRect r(position(), sz);
     sz = r.intersect(_parent->geometry()).size();
   }
-    
+
   return sz;
 }
 
+
 void KstViewLegend::modifiedLegendEntry() {
   setDirty();
 }
 
+
 bool KstViewLegend::layoutPopupMenu(KPopupMenu *menu, const QPoint& pos, KstViewObjectPtr topLevelParent) {
   return KstViewObject::layoutPopupMenu(menu, pos, topLevelParent);
 }
@@ -611,6 +618,7 @@ void KstViewLegend::setCurveList(Kst2DPlotPtr pl) {
   setDirty();
 }
 
+
 void KstViewLegend::reparseTitle() {
   delete _parsedTitle;
   _parsedTitle = Label::parse(_title, true, false);
@@ -621,7 +629,7 @@ void KstViewLegend::reparseTitle() {
 
 
 bool KstViewLegend::fillConfigWidget(QWidget *w, bool isNew) const {
-  ViewLegendWidget *widget = dynamic_cast<ViewLegendWidget*>(w);
+  KstViewLegendWidgetI *widget = dynamic_cast<KstViewLegendWidgetI*>(w);
   if (!widget) {
     return false;
   }
@@ -677,7 +685,7 @@ bool KstViewLegend::fillConfigWidget(QWidget *w, bool isNew) const {
 
 
 bool KstViewLegend::readConfigWidget(QWidget *w, bool editMultipleMode) {
-  ViewLegendWidget *widget = dynamic_cast<ViewLegendWidget*>(w);
+  KstViewLegendWidgetI *widget = dynamic_cast<KstViewLegendWidgetI*>(w);
   if (!widget) {
     return false;
   }
@@ -754,7 +762,7 @@ bool KstViewLegend::readConfigWidget(QWidget *w, bool editMultipleMode) {
 
 
 void KstViewLegend::connectConfigWidget(QWidget *parent, QWidget *w) const {
-  ViewLegendWidget *widget = dynamic_cast<ViewLegendWidget*>(w);
+  KstViewLegendWidgetI *widget = dynamic_cast<KstViewLegendWidgetI*>(w);
   if (!widget) {
     return;
   }
@@ -782,12 +790,12 @@ void KstViewLegend::connectConfigWidget(QWidget *parent, QWidget *w) const {
 
 
 QWidget *KstViewLegend::configWidget(QWidget *parent) {
-  return new ViewLegendWidget(parent, "custom");
+  return new KstViewLegendWidgetI(parent, "custom");
 }
 
 
 void KstViewLegend::populateEditMultiple(QWidget *w) {
-  ViewLegendWidget *widget = dynamic_cast<ViewLegendWidget*>(w);
+  KstViewLegendWidgetI *widget = dynamic_cast<KstViewLegendWidgetI*>(w);
   if (!widget) {
     return;
   }
@@ -877,18 +885,22 @@ void KstViewLegend::setTitle(const QString& title_in) {
   }
 }
 
+
 bool KstViewLegend::trackContents() const {
   return _trackContents;
 }
 
+
 void KstViewLegend::setTrackContents( bool track) {
   _trackContents = track;
 }
 
+
 KstBaseCurveList& KstViewLegend::curves() {
   return _curves;
 }
 
+
 KstViewLegendList KstViewLegend::globalLegendList() {
   KstViewLegendList rc;
   KstApp *app = KstApp::inst();
@@ -907,6 +919,7 @@ KstViewLegendList KstViewLegend::globalLegendList() {
   return rc;
 }
 
+
 namespace {
 KstViewObject *create_KstViewLegend() {
   return new KstViewLegend;
