@@ -101,9 +101,12 @@ KstViewObject::KstViewObject(const QDomElement& e)
 KstViewObject::KstViewObject(const KstViewObject& viewObject)
 : KstObject() {
   _parent = 0L;
+  _newTitle = viewObject._newTitle;
+  _editTitle = viewObject._editTitle;
   _foregroundColor = viewObject._foregroundColor;
   _backgroundColor = viewObject._backgroundColor;
   _aspect = viewObject._aspect;
+  _margins = viewObject._margins;
   _idealSize = viewObject._idealSize;
   _standardActions = viewObject._standardActions;
   _layoutActions = viewObject._layoutActions;
@@ -192,7 +195,6 @@ void KstViewObject::loadChildren(const QDomElement& e) {
           }
           plotNode = plotNode.nextSibling();
         }
-        // FIXME: View Object should not know about this!!!!
         Kst2DPlotMap *pmap = KstApp::inst()->plotHolderWhileOpeningDocument();
         if (pmap->count(in_tag) > 0) {
           Kst2DPlotPtr plot = (*pmap)[in_tag];
@@ -202,7 +204,6 @@ void KstViewObject::loadChildren(const QDomElement& e) {
             pmap->erase(in_tag);
           }
         }
-        // FIXME: use the factories for these in the future
       } else if (el.tagName() == "PlotGroup" || el.tagName() == "plotgroup" /* 1.1 support */) {
         KstPlotGroupPtr plotGroup = new KstPlotGroup(el);
         appendChild(plotGroup.data(), true);
@@ -336,14 +337,6 @@ void KstViewObject::paint(KstPainter& p, const QRegion& bounds) {
   p.save();
   p.setViewport(geometry());
   p.setWindow(geometry());
-
-#if 0
-  // PREFIXME: this causes a redraw each time, bad.
-  // FIXME: ugly hack, just temporary until updates are working.
-  if (type() == "Plot") {
-    setDirty();
-  }
-#endif
   paintUpdate();
 
   bool nullBounds = bounds.isNull();
@@ -422,7 +415,7 @@ void KstViewObject::paintSelf(KstPainter& p, const QRegion& bounds) {
 void KstViewObject::updateSelf() {
   if (dirty()) {
     if (!_maximized) {
-      updateFromAspect(); // FIXME: this shouldn't be necessary.  bug is elsewhere
+      updateFromAspect();
     }
     invalidateClipRegion();
   }
@@ -436,7 +429,6 @@ void KstViewObject::paintUpdate() {
 
 
 void KstViewObject::drawFocusRect(KstPainter& p) {
-  // to draw a focus rect, put something here
   // draw the 8 hotpoints
   const QRect geom(geometry());
   const QPoint topLeft(geom.topLeft());
@@ -781,13 +773,34 @@ void KstViewObject::cleanupGridLayout(int cols, KstViewObjectList &childrenCopy)
     int row;
     int col;
     int rows = ( cnt + cols - 1 ) / cols;
-    QSize sz(_geom.width() / cols, _geom.height() / rows);
+    QSize sz;
+
+    int marginLeftPixels = 0;
+    int marginRightPixels = 0;
+    int marginTopPixels = 0;
+    int marginBottomPixels = 0;
+
+    if (_margins.left >= 0.0 && _margins.right >= 0.0 ) {
+      if (_margins.left + _margins.right < 0.5) {
+        marginLeftPixels = (int)((double)_geom.width() * _margins.left);
+        marginRightPixels = (int)((double)_geom.width() * _margins.right);
+      }
+    }
+    if (_margins.top >= 0.0 && _margins.bottom >= 0.0 ) {
+      if (_margins.top + _margins.bottom < 0.5) {
+        marginTopPixels = (int)((double)_geom.height() * _margins.top);
+        marginBottomPixels = (int)((double)_geom.height()* _margins.bottom);
+      }
+    }
+
+    sz.setWidth((_geom.width() - marginLeftPixels - marginRightPixels) / cols);
+    sz.setHeight((_geom.height() - marginTopPixels - marginBottomPixels) / rows);
 
     for (col=0; col<cols; ++col) {
       for (row=0; row<rows; ++row) {
         if (col + (row * cols) < cnt) {
           KstViewObjectPtr plot = childrenCopy[col + (row * cols)];
-          QPoint pt(sz.width() * col, sz.height() * row);
+          QPoint pt(marginLeftPixels + (sz.width() * col), marginTopPixels + (sz.height() * row));
 
           plot->move(pt);
           plot->resize(sz);
@@ -890,31 +903,50 @@ void KstViewObject::cleanupRandomLayout(int cols, KstViewObjectList &childrenCop
       sum_HR += HR[row];
     }
 
+    int marginLeftPixels = 0;
+    int marginRightPixels = 0;
+    int marginTopPixels = 0;
+    int marginBottomPixels = 0;
+
+    if (_margins.left >= 0.0 && _margins.right >= 0.0 ) {
+      if (_margins.left + _margins.right < 0.5) {
+        marginLeftPixels = (int)((double)_geom.width() * _margins.left);
+        marginRightPixels = (int)((double)_geom.width() * _margins.right);
+      }
+    }
+    if (_margins.top >= 0.0 && _margins.bottom >= 0.0 ) {
+      if (_margins.top + _margins.bottom < 0.5) {
+        marginTopPixels = (int)((double)_geom.height() * _margins.top);
+        marginBottomPixels = (int)((double)_geom.height() * _margins.bottom);
+      }
+    }
+
     //
     // now actually move/resize the plots
     //
-    int w = _geom.width() / cols;
+    int w = (_geom.width() - marginLeftPixels - marginRightPixels)/ cols;
     int h = 0;
-    int y = 0;
+    int y = marginTopPixels;
 
     for (row=0; row<rows; row++) {
       y += h;
-      h = int(double(_geom.height()) * HR[row]/sum_HR);
+      h = int(double((_geom.height() - marginTopPixels - marginBottomPixels) * HR[row]/sum_HR));
       for (col=0; col<cols; col++) {
         CR = col + row*cols;
         if (plotLoc[CR] >= 0) {
           QSize sz(w, h);
+
           row = CR / cols;
           col = CR % cols;
-          QPoint pt(w*col, y);
+          QPoint pt((w*col) + marginLeftPixels, y);
 
           // if necessary adjust the last column so that we don't spill over
           if (col == cols-1) {
             // only adjust the final width if necessary as we would rather have a gap
             // at the right edge of the window than a column of plots that is significantly 
             // wider than all the others
-            if (w*cols > _geom.width()) {
-              sz.setWidth(_geom.width() - w*col);
+            if (w*cols > _geom.width() - marginRightPixels) {
+              sz.setWidth(_geom.width() - (w*col) - marginLeftPixels -marginRightPixels);
             }
           }
 
@@ -923,8 +955,8 @@ void KstViewObject::cleanupRandomLayout(int cols, KstViewObjectList &childrenCop
             // only adjust the final height if necessary as we would rather have a gap
             // at the bottom edge of the window than a row of plots that is significantly 
             // taller than all the others
-            if (y + h > _geom.height()) {
-              sz.setHeight(_geom.height() - y);
+            if (y + h > _geom.height() - marginBottomPixels) {
+              sz.setHeight(_geom.height() - marginBottomPixels - y);
             }
           }
 
@@ -1701,10 +1733,12 @@ void KstViewObject::rename() {
   bool ok = false;
   bool done;
   QString oldName = tagName();
+  QString newName;
+
 #if KDE_VERSION >= KDE_MAKE_VERSION(3,3,0)
-  QString newName = KInputDialog::getText(i18n("Kst"), i18n("Enter a new name for %1:").arg(tagName()), tagName(), &ok);
+  newName = KInputDialog::getText(i18n("Kst"), i18n("Enter a new name for %1:").arg(tagName()), tagName(), &ok);
 #else
-  QString newName = KLineEditDlg::getText(i18n("Enter a new name for %1:").arg(tagName()), tagName(), &ok, 0L);
+  newName = KLineEditDlg::getText(i18n("Enter a new name for %1:").arg(tagName()), tagName(), &ok, 0L);
 #endif
   done = !ok;
   while (!done) {
@@ -1723,6 +1757,7 @@ void KstViewObject::rename() {
 
   if (ok) {
     setTagName(KstObjectTag(newName, KstObjectTag::globalTagContext)); // FIXME: handle tag context
+     KstApp::inst()->updateViewManager(true);
   } else {
     setTagName(KstObjectTag(oldName, KstObjectTag::globalTagContext)); // FIXME: handle tag context
   }
@@ -1966,6 +2001,12 @@ const QString& KstViewObject::editTitle() const {
   return _editTitle;
 }
 
+
+const QString& KstViewObject::newTitle() const {
+  return _newTitle;
+}
+
+
 void KstViewObject::setMinimumSize(const QSize& sz) {
   _minimumSize = sz.expandedTo(QSize(1, 1)); // 1,1 is the absolute minimum
 }
