@@ -80,10 +80,8 @@ QDragObject *KstViewWidget::dragObject() {
 
 
 void KstViewWidget::enterEvent(QEvent *e) {
-  //kstdDebug() << "Enter event" << endl;
   if (_view->viewMode() != KstTopLevelView::DisplayMode) {
     if (!_menu && !_view->tracking()) {
-      //kstdDebug() << "Turning on tracking again" << endl;
       _view->clearFocus();
     }
   }
@@ -101,17 +99,14 @@ void KstViewWidget::focusOutEvent(QFocusEvent *e) {
 
 
 void KstViewWidget::leaveEvent(QEvent *e) {
-  //kstdDebug() << "Leave event" << endl;
   QWidget::leaveEvent(e);
   if (_view->viewMode() != KstTopLevelView::DisplayMode) {
     if (_menu) {
       return;
     }
     if (!_view->tracking()) {
-      //kstdDebug() << "Not tracking" << endl;
       _view->clearFocus();
     } else {
-      //kstdDebug() << "Tracking" << endl;
       if (_view->trackingIsMove() && _dragEnabled) {
         QDragObject *d = dragObject();
         if (d) {
@@ -167,7 +162,6 @@ void KstViewWidget::mouseMoveEvent(QMouseEvent *e) {
     }
 
     if (vo) {
-      //kstdDebug() << "Found mouse handler " << vo->tagName() << endl;
       vo->mouseMoveEvent(this, e);
     } else {
       setCursor(QCursor(Qt::ArrowCursor));
@@ -187,7 +181,6 @@ void KstViewWidget::mouseMoveEvent(QMouseEvent *e) {
       _view->updateFocus(e->pos());
       e->accept();
     } else if (e->state() & Qt::LeftButton) {
-      //setCursor(QCursor(Qt::ArrowCursor));
       _view->pressMove(e->pos(), e->state() & Qt::ShiftButton, e->state() & Qt::AltButton);
       e->accept();
     }
@@ -196,10 +189,9 @@ void KstViewWidget::mouseMoveEvent(QMouseEvent *e) {
 
 
 void KstViewWidget::mousePressEvent(QMouseEvent *e) {
-  //kstdDebug() << "Press event. button=" << e->button() << " state=" << e->state() << endl;
-
   if (_menu) {
     QWidget::mousePressEvent(e);
+
     return;
   }
 
@@ -211,42 +203,40 @@ void KstViewWidget::mousePressEvent(QMouseEvent *e) {
       vo = findChildFor(e->pos());
     }
     if (vo) {
-      //kstdDebug() << "Found mouse handler " << vo->tagName() << endl;
       vo->mousePressEvent(this, e);
     }
+
     return;
   }
 
   // Layout/graphics mode
   if (e->button() & Qt::LeftButton) {
     setCursor(QCursor(Qt::ArrowCursor));
-    //kstdDebug() << "    -> left button" << endl;
     if (_view->handlePress(e->pos(), e->state() & Qt::ShiftButton)) {
-      //kstdDebug() << "   -> Accepting" << endl;
       e->accept();
+
       return;
     } else if (_view->tracking()) {
-      //kstdDebug() << "   -> Swallowing" << endl;
-      e->accept(); // swallow
+      e->accept();
+
       return;
     }
   }
-  //kstdDebug() << "   -> Passing up" << endl;
+
   QWidget::mousePressEvent(e);
 }
 
 
 void KstViewWidget::mouseDoubleClickEvent(QMouseEvent *e) {
-  //kstdDebug() << "DoubleClick event. button=" << e->button() << " state=" << e->state() << endl;
   if (_view->viewMode() == KstTopLevelView::DisplayMode) {
     KstViewObjectPtr vo;
+
     if (_view->mouseGrabbed()) {
       vo = _view->mouseGrabber();
     } else {
       vo = findChildFor(e->pos());
     }
     if (vo) {
-      //kstdDebug() << "Found mouse handler " << vo->tagName() << endl;
       vo->mouseDoubleClickEvent(this, e);
     }
     return;
@@ -261,7 +251,6 @@ void KstViewWidget::mouseDoubleClickEvent(QMouseEvent *e) {
     }
   }
 
-  //kstdDebug() << "   -> Passing up" << endl;
   QWidget::mouseDoubleClickEvent(e);
 }
 
@@ -275,7 +264,6 @@ void KstViewWidget::wheelEvent(QWheelEvent *e) {
       vo = findChildFor(e->pos());
     }
     if (vo) {
-      //kstdDebug() << "Found mouse handler " << vo->tagName() << endl;
       vo->wheelEvent(this, e);
     }
     return;
@@ -284,7 +272,6 @@ void KstViewWidget::wheelEvent(QWheelEvent *e) {
 
 
 void KstViewWidget::mouseReleaseEvent(QMouseEvent *e) {
-  //kstdDebug() << "Release event. button=" << e->button() << " state=" << e->state() << endl;
   if (_view->viewMode() == KstTopLevelView::DisplayMode) {
     KstViewObjectPtr vo;
     if (_view->mouseGrabbed()) {
@@ -293,7 +280,6 @@ void KstViewWidget::mouseReleaseEvent(QMouseEvent *e) {
       vo = findChildFor(e->pos());
     }
     if (vo) {
-      //kstdDebug() << "Found mouse handler " << vo->tagName() << endl;
       vo->mouseReleaseEvent(this, e);
     }
     return;
@@ -302,12 +288,12 @@ void KstViewWidget::mouseReleaseEvent(QMouseEvent *e) {
   if ((e->state() & Qt::ShiftButton) && (e->button() & Qt::LeftButton) && !_view->tracking()) {
     _view->releasePress(e->pos(), true);
   } else if (e->button() & Qt::LeftButton) {
-    //kstdDebug() << "doing releasePress" << endl;
     _view->releasePress(e->pos(), e->state() & Qt::ShiftButton);
     e->accept();
   } else {
     if (e->state() & Qt::LeftButton && _view->tracking()) {
-      e->accept(); // swallow
+      e->accept();
+
       return;
     }
     _view->updateFocus(e->pos());
@@ -319,6 +305,7 @@ void KstViewWidget::mouseReleaseEvent(QMouseEvent *e) {
 void KstViewWidget::contextMenuEvent(QContextMenuEvent *e) {
   if (e->state() & Qt::LeftButton || _view->tracking()) {
     e->ignore();
+
     return;
   }
 
@@ -326,16 +313,17 @@ void KstViewWidget::contextMenuEvent(QContextMenuEvent *e) {
     _view->releaseMouse(_view->mouseGrabber());
   }
 
-  if (_menu) { // Do not allow recursive menus
+  //
+  // do not allow recursive menus
+  //
+  if (_menu) {
     e->ignore();
     return;
   }
 
   _menu = new KPopupMenu(this);
-  //kstdDebug() << "Querying for the popup" << endl;
   bool rc = _view->popupMenu(_menu, e->pos());
   if (rc && _menu->count() > 0) {
-    //kstdDebug() << "Showing the popup." << endl;
     _menu->popup(mapToGlobal(e->pos()));
     connect(_menu, SIGNAL(aboutToHide()), this, SLOT(menuHiding()));
   } else {
@@ -362,6 +350,7 @@ void KstViewWidget::paintEvent(QPaintEvent *e) {
   QTime t;
   t.start();
 #endif
+
   if (e) {  // Resize/expose/etc triggered by X11
     QRegion r = e->region();
     if (r.isEmpty()) {
@@ -371,12 +360,14 @@ void KstViewWidget::paintEvent(QPaintEvent *e) {
       //kstdDebug() << "Paint event with region " << e->region() << endl;
       _view->paint(KstPainter::P_PAINT, e->region());
     }
+
 #ifdef BENCHMARK
     int x = t.elapsed();
     kstdDebug() << "Paint event: X11 triggered - " << x << "ms" << endl;
 #endif
   } else { // explicitly forced paint in the code
     _view->paint(KstPainter::P_ZOOM);
+
 #ifdef BENCHMARK
     int x = t.elapsed();
     kstdDebug() << "Paint event: Forced (zoom) - " << x << "ms" << endl;
