@@ -515,6 +515,14 @@ bool KstVvDialogI::editSingleObject(KstVectorViewPtr vvPtr) {
   }
 
   vvPtr->writeLock();
+  vvPtr->setRecursed(false);
+  if (vvPtr->recursion()) {
+    vvPtr->setRecursed(true);
+    vvPtr->unlock();
+    KMessageBox::error(this, i18n("There is a recursion resulting from the vector view you entered."));
+    return false;
+  }
+
   vvPtr->setDirty();
   vvPtr->unlock();
 
