@@ -35,6 +35,7 @@ void KstBaseCurve::commonConstructor() {
   NS = 0;
 
   _ignoreAutoScale = false;
+  _yVectorOffset = false;
   _parsedLegendTag = 0L;
 }
 
@@ -58,6 +59,22 @@ void KstBaseCurve::setIgnoreAutoScale(bool ignoreAutoScale) {
 }
 
 
+void KstBaseCurve::setYVectorOffset(bool yVectorOffset) {
+  setDirty();
+  _yVectorOffset = yVectorOffset;
+}
+
+
+double KstBaseCurve::yVectorOffsetValue() const {
+  return 0.0;
+}
+
+
+void KstBaseCurve::setYVectorOffsetScalar(const KstScalarPtr& scalar) {
+  Q_UNUSED(scalar);
+}
+
+
 void KstBaseCurve::updateParsedLegendTag() {
   delete _parsedLegendTag;
 
