@@ -29,7 +29,6 @@
 // context for rendering a curve in a plot
 class KstCurveRenderContext {
   public:
-    // FIXME: use reasonable defaults
     KstCurveRenderContext() : p(0L), Lx(0.0), Hx(0.0), Ly(0.0), Hy(0.0),
                               m_X(0.0), m_Y(0.0), b_X(0.0), b_Y(0.0),
                               x_max(0.0), y_max(0.0), x_min(0.0), y_min(0.0),
@@ -73,6 +72,10 @@ class KST_EXPORT KstBaseCurve : public KstDataObject {
 
     virtual void setIgnoreAutoScale(bool ignoreAutoScale);
     virtual bool ignoreAutoScale() const { return _ignoreAutoScale; }
+    virtual void setYVectorOffset(bool yVectorOffset);
+    virtual bool yVectorOffset() const { return _yVectorOffset; }
+    virtual void setYVectorOffsetScalar(const KstScalarPtr& scalar);
+    virtual double yVectorOffsetValue() const;
 
     virtual int samplesPerFrame() const { return 1; }
 
@@ -84,10 +87,10 @@ class KST_EXPORT KstBaseCurve : public KstDataObject {
     virtual double maxY() const { return _maxY; }
     virtual double minY() const { return _minY; }
     virtual double minPosY() const { return _minPosY; }
-    virtual double ns_maxX()    const { return _ns_maxx; }
-    virtual double ns_minX()    const { return _ns_minx; }
-    virtual double ns_maxY()    const { return _ns_maxy; }
-    virtual double ns_minY()    const { return _ns_miny; }
+    virtual double ns_maxX() const { return _ns_maxx; }
+    virtual double ns_minX() const { return _ns_minx; }
+    virtual double ns_maxY() const { return _ns_maxy; }
+    virtual double ns_minY() const { return _ns_miny; }
     virtual double minPosX() const { return _minPosX; }
     virtual double midX() const { return (_maxX+_minX)*0.5; }
     virtual double midY() const { return (_maxY+_minY)*0.5; }
@@ -138,6 +141,7 @@ class KST_EXPORT KstBaseCurve : public KstDataObject {
     double _minY;
     double _minPosY;
     bool _ignoreAutoScale;
+    bool _yVectorOffset;
     int NS;
 
   private:
