@@ -267,6 +267,11 @@ QString KstCSD::vTag() const {
 }
 
 
+KstVectorPtr KstCSD::vector() {
+  return _inputVectors[INVECTOR];
+}
+
+
 void KstCSD::setVector(KstVectorPtr new_v) {
   KstVectorPtr v = _inputVectors[INVECTOR];
 
