@@ -55,6 +55,7 @@ static const QString& EXVECTOR = KGlobal::staticQString("EX");
 static const QString& EYVECTOR = KGlobal::staticQString("EY");
 static const QString& EXMINUSVECTOR = KGlobal::staticQString("EXMinus");
 static const QString& EYMINUSVECTOR = KGlobal::staticQString("EYMinus");
+static const QString& YOFFSETSCALAR = KGlobal::staticQString("YOffset");
 
 KstVCurve::KstVCurve(const QString &in_tag, KstVectorPtr in_X, KstVectorPtr in_Y,
                       KstVectorPtr in_EX, KstVectorPtr in_EY,
@@ -102,7 +103,11 @@ KstVCurve::KstVCurve(const QString &in_tag, KstVectorPtr in_X, KstVectorPtr in_Y
 
 KstVCurve::KstVCurve(QDomElement &e)
 : KstBaseCurve(e) {
-  QString in_tag, xname, yname, exname, eyname, exminusname, eyminusname;
+  QString in_tag;
+  QString xname, yname;
+  QString exname, eyname;
+  QString exminusname, eyminusname;
+  QString yVectorOffsetScalarName;
   QColor in_color("red");
   bool hasMinus = false;
 
@@ -164,6 +169,10 @@ KstVCurve::KstVCurve(QDomElement &e)
         _pointDensity = e.text().toInt();
       } else if (e.tagName() == "ignoreAutoScale") {
         _ignoreAutoScale = true;
+      } else if (e.tagName() == "yVectorOffset") {
+        _yVectorOffset = true;
+      } else if (e.tagName() == "yVectorOffsetScalar") {
+         yVectorOffsetScalarName = e.text();
       } else if (e.tagName() == "interp") {
         _interp = KstVCurve::InterpType(e.text().toInt());
       }
@@ -189,6 +198,10 @@ KstVCurve::KstVCurve(QDomElement &e)
   if (!eyminusname.isEmpty()) {
     _inputVectorLoadQueue.append(qMakePair(EYMINUSVECTOR, eyminusname));
   }
+  if (!yVectorOffsetScalarName.isEmpty()) {
+    _inputScalarLoadQueue.append(qMakePair(YOFFSETSCALAR, yVectorOffsetScalarName));
+  }
+
   commonConstructor(in_tag, in_color);
 }
 
@@ -470,6 +483,15 @@ KstObjectTag KstVCurve::yEMinusTag() const {
 }
 
 
+KstObjectTag KstVCurve::yVectorOffsetTag() const {
+  KstScalarPtr s = yVectorOffsetScalar();
+  if (s) {
+    return s->tag();
+  }
+  return KstObjectTag::invalidTag;
+}
+
+
 bool KstVCurve::hasXError() const {
   return _inputVectors.contains(EXVECTOR);
 }
@@ -529,6 +551,10 @@ void KstVCurve::save(QTextStream &ts, const QString& indent) {
   if (_ignoreAutoScale) {
     ts << l2 << "<ignoreAutoScale/>" << endl;
   }
+  if (_yVectorOffset) {
+    ts << l2 << "<yVectorOffset/>" << endl;
+    ts << l2 << "<yVectorOffsetScalar>" << QStyleSheet::escape(_inputScalars[YOFFSETSCALAR]->tag().tagString()) << "</yVectorOffsetScalar>" << endl;
+  }
   ts << indent << "</curve>" << endl;
 }
 
@@ -665,6 +691,11 @@ KstVectorPtr KstVCurve::yMinusErrorVector() const {
 }
 
 
+KstScalarPtr KstVCurve::yVectorOffsetScalar() const {
+  return *_inputScalars.find(YOFFSETSCALAR);
+}
+
+
 bool KstVCurve::xIsRising() const {
   return _inputVectors[COLOR_XVECTOR]->isRising();
 }
@@ -858,6 +889,32 @@ double KstVCurve::minX() const {
 }
 
 
+void KstVCurve::setYVectorOffsetScalar(const KstScalarPtr& scalar) {
+  if (scalar) {
+    _inputScalars[YOFFSETSCALAR] = scalar;
+  } else {
+    _inputScalars.remove(YOFFSETSCALAR);
+  }
+  setDirty();
+}
+
+
+double KstVCurve::yVectorOffsetValue() const {
+  double value = 0.0;
+
+  if (_yVectorOffset) {
+    KstScalarPtr scalar;
+
+    scalar = *_inputScalars.find(YOFFSETSCALAR);
+    if (scalar) {
+      value = -scalar->value();
+    }
+  }
+
+  return value;
+}
+
+
 KstDataObjectPtr KstVCurve::makeDuplicate(KstDataObjectDataObjectMap& duplicatedMap) {
   KstVectorPtr VX = *_inputVectors.find(COLOR_XVECTOR);
   KstVectorPtr VY = *_inputVectors.find(COLOR_YVECTOR);
@@ -879,6 +936,11 @@ KstDataObjectPtr KstVCurve::makeDuplicate(KstDataObjectDataObjectMap& duplicated
   vcurve->setLineWidth(_lineWidth);
   vcurve->setLineStyle(_lineStyle);
   vcurve->setPointDensity(_pointDensity);
+  vcurve->setIgnoreAutoScale(_ignoreAutoScale);
+  vcurve->setYVectorOffset(_yVectorOffset);
+  if (_inputScalars.find(YOFFSETSCALAR) != _inputScalars.end()) {
+    vcurve->setYVectorOffsetScalar(*_inputScalars.find(YOFFSETSCALAR));
+  }
 
   duplicatedMap.insert(this, KstDataObjectPtr(vcurve));
   return KstDataObjectPtr(vcurve);
@@ -894,29 +956,47 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
 
   KstPainter *p = context.p;
   QColor foregroundColor = context.foregroundColor;
-  double Lx = context.Lx, Hx = context.Hx, Ly = context.Ly, Hy = context.Hy;
-  double m_X = context.m_X, m_Y = context.m_Y;
-  double b_X = context.b_X, b_Y = context.b_Y;
-  double XMin = context.XMin, XMax = context.XMax;
-  bool xLog = context.xLog, yLog = context.yLog;
+  double Lx = context.Lx;
+  double Hx = context.Hx;
+  double Ly = context.Ly;
+  double Hy = context.Hy;
+  double m_X = context.m_X;
+  double m_Y = context.m_Y;
+  double b_X = context.b_X;
+  double b_Y = context.b_Y;
+  double XMin = context.XMin;
+  double XMax = context.XMax;
+  bool xLog = context.xLog;
+  bool yLog = context.yLog;
   double xLogBase = context.xLogBase;
   double yLogBase = context.yLogBase;
   int penWidth = context.penWidth;
   double maxY = 0.0, minY = 0.0;
-  double rX = 0.0, rY, rEX, rEY;
+  double rX = 0.0, rY = 0.0;
+  double rEX = 0.0, rEY = 0.0;
   double X1 = 0.0, Y1 = 0.0;
   double X2 = 0.0, Y2 = 0.0;
   double last_x1, last_y1;
+  double yOffset = 0.0;
   bool overlap = false;
   int i_pt;
 
 #ifdef BENCHMARK
-  QTime bench_time, benchtmp;
-  int b_1 = 0, b_2 = 0, b_3 = 0, b_4 = 0;
+  QTime bench_time;
+  QTime benchtmp;
+  int benchmark0 = 0;
+  int benchmark1 = 0;
+  int benchmark2 = 0;
+  int benchmark3 = 0;
+
   bench_time.start();
   benchtmp.start();
 #endif
 
+  if (!yLog) {
+    yOffset = yVectorOffsetValue();
+  }
+
   int pointDim = KstCurvePointSymbol::dim(p);
   if (sampleCount() > 0) {
     Qt::PenStyle style = KstLineStyle[lineStyle()];
@@ -946,6 +1026,7 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
 #ifdef BENCHMARK
     clock_t linesStart = clock();
 #endif
+
     if (hasLines()) {
       QPointArray points(MAX_NUM_POLYLINES);
       int lastPlottedX = 0;
@@ -977,7 +1058,7 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
           rY = yv->interpolate(i0, NS);
         }
       }
- 
+
       if (xLog) {
         rX = logXLo(rX, xLogBase);
       }
@@ -985,7 +1066,7 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
         rY = logYLo(rY, yLogBase);
       }
       last_x1 = m_X*rX + b_X;
-      last_y1 = m_Y*rY + b_Y;
+      last_y1 = m_Y*(rY + yOffset) + b_Y;
 
       i_pt = i0;
 
@@ -1033,7 +1114,8 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
           rY = logYLo(rY, yLogBase);
         }
         X1 = m_X*rX + b_X;
-        Y1 = m_Y*rY + b_Y;
+        Y1 = m_Y*(rY + yOffset) + b_Y;
+
         last_x1 = X1;
         last_y1 = Y1;
 
@@ -1232,7 +1314,7 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
 #ifdef BENCHMARK
     clock_t linesEnd = clock();
     kstdDebug() << "        Lines clocks: " << (linesEnd - linesStart) << endl;
-    b_1 = benchtmp.elapsed();
+    benchmark0 = benchtmp.elapsed();
 #endif
 
     KstVectorPtr exv = *_inputVectors.find(EXVECTOR);
@@ -1311,7 +1393,7 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
 
         // determine where the top of the bar is and whether
         // to draw the top line
-        Y1 = m_Y * rY + b_Y;
+        Y1 = m_Y * (rY + yVectorOffsetValue()) + b_Y;
         if (Y1 < Ly) {
           Y1 = Ly;
           has_top = false;
@@ -1372,8 +1454,9 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
     }
 
 #ifdef BENCHMARK
-    b_2 = benchtmp.elapsed();
+    benchmark1 = benchtmp.elapsed();
 #endif
+
     QPen pen(color(), width);
     pen.setCapStyle(Qt::RoundCap);
     p->setPen(pen);
@@ -1399,7 +1482,7 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
           }
 
           pt.setX(d2i(m_X * rX + b_X));
-          pt.setY(d2i(m_Y * rY + b_Y));
+          pt.setY(d2i(m_Y * (rY + yOffset) + b_Y));
           if (rgn.contains(pt)) {
             KstCurvePointSymbol::draw(_pointStyle, p, pt.x(), pt.y(), width);
             rgn -= QRegion(pt.x()-(size/2), pt.y()-(size/2), size, size, QRegion::Ellipse);
@@ -1417,7 +1500,7 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
           }
 
           X1 = m_X * rX + b_X;
-          Y1 = m_Y * rY + b_Y;
+          Y1 = m_Y * (rY + yOffset) + b_Y;
           if (X1 >= Lx && X1 <= Hx && Y1 >= Ly && Y1 <= Hy) {
             KstCurvePointSymbol::draw(_pointStyle, p, d2i(X1), d2i(Y1), width);
           }
@@ -1426,7 +1509,7 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
     }
 
 #ifdef BENCHMARK
-    b_3 = benchtmp.elapsed();
+    benchmark2 = benchtmp.elapsed();
 #endif
 
     // draw the x-errors, if any...
@@ -1494,7 +1577,7 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
 
         X1 = m_X * rX1 + b_X;
         X2 = m_X * rX2 + b_X;
-        Y1 = m_Y * rY + b_Y;
+        Y1 = m_Y * (rY + yOffset) + b_Y;
 
         if (X1 < Lx && X2 > Lx) {
           X1 = Lx;
@@ -1592,8 +1675,8 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
         }
 
         X1 = m_X * rX + b_X;
-        Y1 = m_Y * rY1 + b_Y;
-        Y2 = m_Y * rY2 + b_Y;
+        Y1 = m_Y * (rY1 + yOffset) + b_Y;
+        Y2 = m_Y * (rY2 + yOffset) + b_Y;
 
         if (Y1 < Ly && Y2 > Ly) {
           Y1 = Ly;
@@ -1628,16 +1711,26 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
   } // end if (sampleCount() > 0)
 
 #ifdef BENCHMARK
-  b_4 = benchtmp.elapsed();
+  benchmark3 = benchtmp.elapsed();
 #endif
+
 #ifdef BENCHMARK
   int i = bench_time.elapsed();
-  kstdDebug() << "Plotting curve " << (void *)this << ": " << i << "ms" << endl;
-  kstdDebug() << "    Without locks: " << b_4 << "ms" << endl;
-  if (b_1 > 0)       kstdDebug() << "            Lines: " << b_1 << "ms" << endl;
-  if (b_2 - b_1 > 0) kstdDebug() << "             Bars: " << (b_2 - b_1) << "ms" << endl;
-  if (b_3 - b_2 > 0) kstdDebug() << "           Points: " << (b_3 - b_2) << "ms" << endl;
-  if (b_4 - b_3 > 0) kstdDebug() << "           Errors: " << (b_4 - b_3) << "ms" << endl;
+
+  kstdDebug() << "Plotting curve " << tagName() << " ("<< (void*)this << ") " << ": " << i << "ms" << endl;
+  kstdDebug() << "    Without locks: " << benchmark3 << "ms" << endl;
+  if (benchmark0 > 0) {
+    kstdDebug() << "            Lines: " << benchmark0 << "ms" << endl;
+  }
+  if (benchmark1 - benchmark0 > 0) {
+    kstdDebug() << "             Bars: " << (benchmark1 - benchmark0) << "ms" << endl;
+  }
+  if (benchmark2 - benchmark1 > 0) {
+    kstdDebug() << "           Points: " << (benchmark2 - benchmark1) << "ms" << endl;
+  }
+  if (benchmark3 - benchmark2 > 0) {
+    kstdDebug() << "           Errors: " << (benchmark3 - benchmark2) << "ms" << endl;
+  }
 #endif
 }
 
