@@ -58,12 +58,16 @@ class KST_EXPORT KstVCurve: public KstBaseCurve {
     virtual void getEXPoints(int i, double &x, double &y, double &ex, double &exminus);
     virtual void getEYPoints(int i, double &x, double &y, double &ey, double &eyminus);
 
+    virtual double yVectorOffsetValue() const;
+    virtual void setYVectorOffsetScalar(const KstScalarPtr& scalar);
+
     KstObjectTag xVTag() const;
     KstObjectTag yVTag() const;
     KstObjectTag xETag() const;
     KstObjectTag yETag() const;
     KstObjectTag xEMinusTag() const;
     KstObjectTag yEMinusTag() const;
+    KstObjectTag yVectorOffsetTag() const;
 
     void setXVector(KstVectorPtr new_vx);
     void setYVector(KstVectorPtr new_vy);
@@ -100,6 +104,7 @@ class KST_EXPORT KstVCurve: public KstBaseCurve {
     KstVectorPtr yErrorVector() const;
     KstVectorPtr xMinusErrorVector() const;
     KstVectorPtr yMinusErrorVector() const;
+    KstScalarPtr yVectorOffsetScalar() const;
 
     virtual bool hasPoints()    const { return _hasPoints; }
     virtual bool hasLines()     const { return _hasLines; }
