@@ -157,7 +157,7 @@ double KstDataRange::f0Value()
 {
     const int cur = _startUnits->currentItem();
     if (cur == KST::dateTimeEntry) {
-	KST::ExtDateTime edt = KST::parsePlanckDate(F0->text());
+	KST::ExtDateTime edt = KST::parsePlanckDate(F0->text(), true);
 	if (edt.isNull()) {
 	    return KST::NOPOINT;
 	}
@@ -180,7 +180,7 @@ KST::ExtDateTime KstDataRange::f0DateTimeValue()
     const int cur = _startUnits->currentItem();
     KST::ExtDateTime edt;
     if (cur == KST::dateTimeEntry) {
-	edt = KST::parsePlanckDate(F0->text());
+	edt = KST::parsePlanckDate(F0->text(), true);
     }
     return edt;
 }
