@@ -81,7 +81,7 @@ QDomDocument makeDOMElement(const QString& tag, const int nx, const int ny, cons
   for (int i = 0; i < dataSize; i++) {
     qds << 1.1;
   }
-  
+
   text = amDOM.createTextNode(QString(KCodecs::base64Encode(qCompress(qba))));
 
   child.appendChild(text);
@@ -94,7 +94,7 @@ QDomDocument makeDOMElement(const QString& tag, const int nx, const int ny, cons
 
 void doTests() {
   bool ok = true;
-  
+
   QDomNode n = makeDOMElement("amDOM", 0, 0, 0, 0, 1, 1, 9).firstChild();
   QDomElement e = n.toElement();
 
@@ -102,14 +102,14 @@ void doTests() {
   KstAMatrix* am1 = new KstAMatrix(e);
   doTest(am1->tagName().startsWith("amDOM"));
   doTest(am1->sampleCount() == 0);
-  doTest(am1->minValue() == 0);
-  doTest(am1->maxValue() == 0);
+  doTest(am1->minValue() == 0.0);
+  doTest(am1->maxValue() == 0.0);
   doTest(am1->value(0, 0, &ok) == 0);
   doTest(!ok);
   doTest(am1->value(10, 10, &ok) == 0); //should be outside the boundaries.
   doTest(!ok);
   doTest(am1->sampleCount() == 0);
-  doTest(am1->meanValue() == 0);
+  doTest(am1->meanValue() != am1->meanValue()); // NaN
 
   //basic symetrical matrix
   n = makeDOMElement("Symetrical", 3, 3, 0, 0, 1, 1, 9).firstChild();
@@ -117,7 +117,7 @@ void doTests() {
 
   //basic default constructor values
   KstAMatrix* am2 = new KstAMatrix(e);
-  
+
   doTest(am2->tagName() == "Symetrical");
   doTest(am2->resize(3, 3, true));
 
@@ -312,7 +312,7 @@ void doTests() {
   sm->calcNoSpikeRange(-100);
   doTest(sm->minValueNoSpike() == 0.0);
   doTest(sm->maxValueNoSpike() == 0.0);
-  
+
   sm->calcNoSpikeRange(0.9);
   doTest(sm->minValueNoSpike() >= 1E+300 );
   doTest(sm->maxValueNoSpike() <= -1E+300);
@@ -320,9 +320,13 @@ void doTests() {
 
 
 int main(int argc, char **argv) {
+  Q_UNUSED(argc);
+  Q_UNUSED(argv);
+
   atexit(exitHelper);
 
-  KApplication app(argc, argv, "testamatrix", false, false);
+  KCmdLineArgs::init(argc, argv, "testamatrix", "testamatrix", "testamatrix", "1.0.0.0");
+  KApplication app(false, false);
 
   doTests();
   // Don't put tests in main because we need to ensure that no KstObjects
