@@ -39,7 +39,7 @@ void doTests() {
   doTest(m1->value(10, 10, &ok) == 0); //should be outside the boundaries.
   doTest(!ok);
   doTest(m1->sampleCount() == 0);
-  doTest(m1->meanValue() == 0);
+  doTest(m1->meanValue() != m1->meanValue()); // NaN
 
   //basic symetrical matrix
   KstMatrixPtr m2 = new KstMatrix(KstObjectTag("Symetrical"), 0L, 3, 3);
@@ -158,7 +158,7 @@ void doTests() {
   doTest(um1->maxValue() == 0);
 
   KstMatrixPtr sm = new KstMatrix(KstObjectTag("Spike"), 0L, 2, 2, 0, 0, 1, 1);
-  
+
   sm->setEditable(true);
   doTest(sm->resize(2, 2, false));
   doTest(sm->xNumSteps() == 2);
@@ -176,7 +176,7 @@ void doTests() {
   sm->calcNoSpikeRange(-100);
   doTest(sm->minValueNoSpike() == 0.0);
   doTest(sm->maxValueNoSpike() == 0.0);
-  
+
   sm->calcNoSpikeRange(0.9);
   doTest(sm->minValueNoSpike() >= 1E+300 );
   doTest(sm->maxValueNoSpike() <= -1E+300);
@@ -184,9 +184,13 @@ void doTests() {
 
 
 int main(int argc, char **argv) {
+  Q_UNUSED(argc);
+  Q_UNUSED(argv);
+
   atexit(exitHelper);
 
-  KApplication app(argc, argv, "testmatrix", false, false);
+  KCmdLineArgs::init(argc, argv, "testmatrix", "testmatrix", "testmatrix", "1.0.0.0");
+  KApplication app(false, false);
 
   doTests();
   // Don't put tests in main because we need to ensure that no KstObjects
@@ -196,5 +200,6 @@ int main(int argc, char **argv) {
   if (rc == KstTestSuccess) {
     printf("All tests passed!\n");
   }
+
   return -rc;
 }
