@@ -200,9 +200,13 @@ void doTests() {
 
 
 int main(int argc, char **argv) {
+  Q_UNUSED(argc);
+  Q_UNUSED(argv);
+
   atexit(exitHelper);
 
-  KApplication app(argc, argv, "testpsd", false, false);
+  KCmdLineArgs::init(argc, argv, "testpsd", "testpsd", "testpsd", "1.0.0.0");
+  KApplication app(false, false);
 
   doTests();
   // Don't put tests in main because we need to ensure that no KstObjects
@@ -212,7 +216,7 @@ int main(int argc, char **argv) {
   if (rc == KstTestSuccess) {
     printf("All tests passed!\n");
   }
+
   return -rc;
 }
 
-// vim: ts=2 sw=2 et
