@@ -24,7 +24,7 @@ void testAssert(bool result, const QString& text = "Unknown") {
     printf("Test [%s] failed.\n", text.latin1());
   }
 }
-    
+
 
 void doTests() {
   KstVectorPtr v1 = new KstVector(KstObjectTag("V1"), 15);
@@ -32,13 +32,13 @@ void doTests() {
   doTest(v1->length() == 15);
   v1->zero();
   for (int i = 0; i < 15; ++i) {
-    doTest(v1->value()[i] == 0);
+    doTest(v1->value()[i] == 0.0);
   }
   doTest(!v1->isScalarList());
-  v1->value()[0] = -42;
+  v1->value()[0] = -42.0;
   v1->resize(3);
   doTest(v1->length() == 3);
-  doTest(v1->value()[0] == -42);
+  doTest(v1->value()[0] == -42.0);
 
   KstVectorPtr v2 = new KstVector(KstObjectTag(QString::null), 0);
   doTest(v2->length() == 1);
@@ -50,21 +50,25 @@ void doTests() {
 
   v2->resize(3);
   double *data = v2->value();
-  data[0] = 1;
-  data[1] = 2;
-  data[2] = 3;
-  doTest(v2->interpolate(0, 5) == 1);
+  data[0] = 1.0;
+  data[1] = 2.0;
+  data[2] = 3.0;
+  doTest(v2->interpolate(0, 5) == 1.0);
   doTest(v2->interpolate(1, 5) == 1.5);
-  doTest(v2->interpolate(2, 5) == 2);
+  doTest(v2->interpolate(2, 5) == 2.0);
   doTest(v2->interpolate(3, 5) == 2.5);
-  doTest(v2->interpolate(4, 5) == 3);
+  doTest(v2->interpolate(4, 5) == 3.0);
 }
 
 
 int main(int argc, char **argv) {
+  Q_UNUSED(argc);
+  Q_UNUSED(argv);
+
   atexit(exitHelper);
 
-  KApplication app(argc, argv, "testvector", false, false);
+  KCmdLineArgs::init(argc, argv, "testvector", "testvector", "testvector", "1.0.0.0");
+  KApplication app(false, false);
 
   doTests();
   // Don't put tests in main because we need to ensure that no KstObjects
@@ -74,7 +78,6 @@ int main(int argc, char **argv) {
   if (rc == KstTestSuccess) {
     printf("All tests passed!\n");
   }
+
   return -rc;
 }
-
-// vim: ts=2 sw=2 et
